@@ -157,7 +157,7 @@ class _DictGetter(t.Generic[_BaseDictT]):
 
     def __getattr__(self, key: str) -> object:
         try:
-            return self.__data[key]
+            return self.__data[key]  # type: ignore[literal-required]
         except KeyError:
             return super().__getattribute__(key)
 
@@ -327,11 +327,12 @@ class BaseFixedMapping(
                 continue
 
             key = arg.key
-            if cg_maybe.Nothing.is_nothing_instance(res[key]):
+            val = res[key]  # type: ignore[literal-required]
+            if cg_maybe.Nothing.is_nothing_instance(val):
                 del res[key]
             else:
-                assert isinstance(res[key], cg_maybe.Just)
-                res[key] = res[key].value  # type: ignore
+                assert isinstance(val, cg_maybe.Just)
+                res[key] = val.value  # type: ignore
 
         return res
 
@@ -434,7 +435,8 @@ class FixedMapping(
         result = self._try_parse(value)
 
         if self.__tag is not None:
-            result[self.__tag[0]] = self.__tag[1]  # type: ignore[misc]
+            result[self.__tag[0]  # type: ignore[literal-required]
+                   ] = self.__tag[1]
         return _DictGetter(result)
 
     def combine(
