@@ -2,6 +2,7 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import os
 import typing as t
 
 import cg_request_args as rqa
@@ -9,34 +10,39 @@ from cg_maybe import Maybe, Nothing
 
 from .. import parsers, utils
 
-if t.TYPE_CHECKING:
-    from ..client import AuthenticatedClient, _BaseClient
+if t.TYPE_CHECKING or os.getenv("CG_EAGERIMPORT", False):
+    import codegrade
+
     from ..models.all_auto_test_results import AllAutoTestResults
-    from ..models.any_error import AnyError
     from ..models.auto_test import AutoTest
     from ..models.auto_test_result import AutoTestResult
     from ..models.auto_test_set import AutoTestSet
     from ..models.auto_test_suite import AutoTestSuite
     from ..models.copy_auto_test_data import CopyAutoTestData
     from ..models.create_auto_test_data import CreateAutoTestData
+    from ..models.create_output_html_proxy_auto_test_data import (
+        CreateOutputHtmlProxyAutoTestData,
+    )
     from ..models.extended_auto_test_result import ExtendedAutoTestResult
     from ..models.extended_auto_test_run import ExtendedAutoTestRun
     from ..models.patch_auto_test_data import PatchAutoTestData
+    from ..models.proxy import Proxy
     from ..models.result_data_get_auto_test_get import ResultDataGetAutoTestGet
     from ..models.update_set_auto_test_data import UpdateSetAutoTestData
     from ..models.update_suite_auto_test_data import UpdateSuiteAutoTestData
 
-_ClientT = t.TypeVar("_ClientT", bound="_BaseClient")
+
+_ClientT = t.TypeVar("_ClientT", bound="codegrade.client._BaseClient")
 
 
 class AutoTestService(t.Generic[_ClientT]):
     __slots__ = ("__client",)
 
-    def __init__(self, client: "_BaseClient") -> None:
+    def __init__(self, client: _ClientT) -> None:
         self.__client = client
 
     def copy(
-        self: "AutoTestService[AuthenticatedClient]",
+        self: "AutoTestService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[dict, list, "CopyAutoTestData"],
         *,
         auto_test_id: "int",
@@ -44,18 +50,18 @@ class AutoTestService(t.Generic[_ClientT]):
             str, t.Union[str, bool, int, float]
         ] = None,
     ) -> "AutoTest":
-        """Copy the given AutoTest configuration.
+        """Copy the given `AutoTest` configuration.
 
         :param json_body: The body of the request. See
-            :model:`.CopyAutoTestData` for information about the possible
-            fields. You can provide this data as a :model:`.CopyAutoTestData`
+            :class:`.CopyAutoTestData` for information about the possible
+            fields. You can provide this data as a :class:`.CopyAutoTestData`
             or as a dictionary.
-        :param auto_test_id: The id of the AutoTest config which should be
+        :param auto_test_id: The id of the `AutoTest` config which should be
             copied.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
 
-        :returns: The copied AutoTest configuration.
+        :returns: The copied `AutoTest` configuration.
         """
 
         url = "/api/v1/auto_tests/{autoTestId}/copy".format(
@@ -91,22 +97,22 @@ class AutoTestService(t.Generic[_ClientT]):
         )
 
     def create(
-        self: "AutoTestService[AuthenticatedClient]",
+        self: "AutoTestService[codegrade.client.AuthenticatedClient]",
         multipart_data: t.Union[dict, list, "CreateAutoTestData"],
         *,
         extra_parameters: t.Mapping[
             str, t.Union[str, bool, int, float]
         ] = None,
     ) -> "AutoTest":
-        """Create a new AutoTest configuration.
+        """Create a new `AutoTest` configuration.
 
         :param multipart_data: The data that should form the body of the
-            request. See :model:`.CreateAutoTestData` for information about the
+            request. See :class:`.CreateAutoTestData` for information about the
             possible fields.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
 
-        :returns: The newly created AutoTest.
+        :returns: The newly created `AutoTest`.
         """
 
         url = "/api/v1/auto_tests/"
@@ -142,17 +148,17 @@ class AutoTestService(t.Generic[_ClientT]):
         )
 
     def add_set(
-        self: "AutoTestService[AuthenticatedClient]",
+        self: "AutoTestService[codegrade.client.AuthenticatedClient]",
         *,
         auto_test_id: "int",
         extra_parameters: t.Mapping[
             str, t.Union[str, bool, int, float]
         ] = None,
     ) -> "AutoTestSet":
-        """Create a new set within an AutoTest
+        """Create a new set within an `AutoTest`
 
-        :param auto_test_id: The id of the AutoTest wherein you want to create
-            a set.
+        :param auto_test_id: The id of the `AutoTest` wherein you want to
+            create a set.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
 
@@ -190,7 +196,7 @@ class AutoTestService(t.Generic[_ClientT]):
         )
 
     def get(
-        self: "AutoTestService[AuthenticatedClient]",
+        self: "AutoTestService[codegrade.client.AuthenticatedClient]",
         *,
         auto_test_id: "int",
         latest_only: "bool" = False,
@@ -200,7 +206,7 @@ class AutoTestService(t.Generic[_ClientT]):
     ) -> "ResultDataGetAutoTestGet":
         """Get the extended version of an `AutoTest` and its runs.
 
-        :param auto_test_id: The id of the AutoTest to get.
+        :param auto_test_id: The id of the `AutoTest` to get.
         :param latest_only: Only retrieve the results of the latest
             submissions.
         :param extra_parameters: The extra query parameters you might want to
@@ -244,19 +250,19 @@ class AutoTestService(t.Generic[_ClientT]):
         )
 
     def delete(
-        self: "AutoTestService[AuthenticatedClient]",
+        self: "AutoTestService[codegrade.client.AuthenticatedClient]",
         *,
         auto_test_id: "int",
         extra_parameters: t.Mapping[
             str, t.Union[str, bool, int, float]
         ] = None,
     ) -> "None":
-        """Delete the given AutoTest.
+        """Delete the given `AutoTest`.
 
-        This route fails if the AutoTest has any runs, which should be deleted
-        separately.
+        This route fails if the `AutoTest` has any runs, which should be
+        deleted separately.
 
-        :param auto_test_id: The AutoTest that should be deleted.
+        :param auto_test_id: The `AutoTest` that should be deleted.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
 
@@ -288,7 +294,7 @@ class AutoTestService(t.Generic[_ClientT]):
         )
 
     def patch(
-        self: "AutoTestService[AuthenticatedClient]",
+        self: "AutoTestService[codegrade.client.AuthenticatedClient]",
         multipart_data: t.Union[dict, list, "PatchAutoTestData"],
         *,
         auto_test_id: "int",
@@ -296,16 +302,16 @@ class AutoTestService(t.Generic[_ClientT]):
             str, t.Union[str, bool, int, float]
         ] = None,
     ) -> "AutoTest":
-        """Update the settings of an AutoTest configuration.
+        """Update the settings of an `AutoTest` configuration.
 
         :param multipart_data: The data that should form the body of the
-            request. See :model:`.PatchAutoTestData` for information about the
+            request. See :class:`.PatchAutoTestData` for information about the
             possible fields.
-        :param auto_test_id: The id of the AutoTest you want to update.
+        :param auto_test_id: The id of the `AutoTest` you want to update.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
 
-        :returns: The updated AutoTest.
+        :returns: The updated `AutoTest`.
         """
 
         url = "/api/v1/auto_tests/{autoTestId}".format(autoTestId=auto_test_id)
@@ -341,7 +347,7 @@ class AutoTestService(t.Generic[_ClientT]):
         )
 
     def get_run(
-        self: "AutoTestService[AuthenticatedClient]",
+        self: "AutoTestService[codegrade.client.AuthenticatedClient]",
         *,
         auto_test_id: "int",
         run_id: "int",
@@ -356,7 +362,7 @@ class AutoTestService(t.Generic[_ClientT]):
         `latest_only` query parameter to a truthy value only the results of
         latest submissions will be provided.
 
-        :param auto_test_id: The id of the AutoTest which is connected to the
+        :param auto_test_id: The id of the `AutoTest` which is connected to the
             requested run.
         :param run_id: The id of the run to get.
         :param latest_only: Only retrieve the results for the latest submission
@@ -401,7 +407,7 @@ class AutoTestService(t.Generic[_ClientT]):
         )
 
     def stop_run(
-        self: "AutoTestService[AuthenticatedClient]",
+        self: "AutoTestService[codegrade.client.AuthenticatedClient]",
         *,
         auto_test_id: "int",
         run_id: "int",
@@ -409,12 +415,13 @@ class AutoTestService(t.Generic[_ClientT]):
             str, t.Union[str, bool, int, float]
         ] = None,
     ) -> "None":
-        """Delete an AutoTest run, this makes it possible to edit the AutoTest.
+        """Delete an `AutoTest` run, this makes it possible to edit the
+        `AutoTest`.
 
-        This also clears the rubric categories filled in by the AutoTest.
+        This also clears the rubric categories filled in by the `AutoTest`.
 
-        :param auto_test_id: The id of the AutoTest of which the run should be
-            deleted.
+        :param auto_test_id: The id of the `AutoTest` of which the run should
+            be deleted.
         :param run_id: The id of the run which should be deleted.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
@@ -449,7 +456,7 @@ class AutoTestService(t.Generic[_ClientT]):
         )
 
     def delete_set(
-        self: "AutoTestService[AuthenticatedClient]",
+        self: "AutoTestService[codegrade.client.AuthenticatedClient]",
         *,
         auto_test_id: "int",
         auto_test_set_id: "int",
@@ -459,10 +466,8 @@ class AutoTestService(t.Generic[_ClientT]):
     ) -> "None":
         """Delete an `AutoTestSet` (also known as level).
 
-        :param auto_test_id: The id of the <span
-            data-role="class">.models.AutoTest</span> of the to be deleted set.
-        :param auto_test_set_id: The id of the <span
-            data-role="class">.models.AutoTestSet</span> that should be
+        :param auto_test_id: The id of the `AutoTest` of the to be deleted set.
+        :param auto_test_set_id: The id of the `AutoTestSet` that should be
             deleted.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
@@ -497,7 +502,7 @@ class AutoTestService(t.Generic[_ClientT]):
         )
 
     def update_set(
-        self: "AutoTestService[AuthenticatedClient]",
+        self: "AutoTestService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[dict, list, "UpdateSetAutoTestData"],
         *,
         auto_test_id: "int",
@@ -509,9 +514,9 @@ class AutoTestService(t.Generic[_ClientT]):
         """Update the given `AutoTestSet` (also known as level).
 
         :param json_body: The body of the request. See
-            :model:`.UpdateSetAutoTestData` for information about the possible
+            :class:`.UpdateSetAutoTestData` for information about the possible
             fields. You can provide this data as a
-            :model:`.UpdateSetAutoTestData` or as a dictionary.
+            :class:`.UpdateSetAutoTestData` or as a dictionary.
         :param auto_test_id: The id of the `AutoTest` of the set that should be
             updated.
         :param auto_test_set_id: The id of the `AutoTestSet` that should be
@@ -555,7 +560,7 @@ class AutoTestService(t.Generic[_ClientT]):
         )
 
     def delete_suite(
-        self: "AutoTestService[AuthenticatedClient]",
+        self: "AutoTestService[codegrade.client.AuthenticatedClient]",
         *,
         test_id: "int",
         set_id: "int",
@@ -566,14 +571,10 @@ class AutoTestService(t.Generic[_ClientT]):
     ) -> "None":
         """Delete an `AutoTestSuite` (also known as category).
 
-        :param test_id: The id of the <span
-            data-role="class">.models.AutoTest</span> where the suite is
-            located in.
-        :param set_id: The id of the <span
-            data-role="class">.models.AutoTestSet</span> where the suite is
-            located in.
-        :param suite_id: The id of the <span
-            data-role="class">.models.AutoTestSuite</span> you want to delete.
+        :param test_id: The id of the `AutoTest` where the suite is located in.
+        :param set_id: The id of the `AutoTestSet` where the suite is located
+            in.
+        :param suite_id: The id of the `AutoTestSuite` you want to delete.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
 
@@ -609,7 +610,7 @@ class AutoTestService(t.Generic[_ClientT]):
         )
 
     def get_result(
-        self: "AutoTestService[AuthenticatedClient]",
+        self: "AutoTestService[codegrade.client.AuthenticatedClient]",
         *,
         auto_test_id: "int",
         run_id: "int",
@@ -618,17 +619,16 @@ class AutoTestService(t.Generic[_ClientT]):
             str, t.Union[str, bool, int, float]
         ] = None,
     ) -> "ExtendedAutoTestResult":
-        """Get the extended version of an AutoTest result.
+        """Get the extended version of an `AutoTest` result.
 
-        :param auto_test_id: The id of the AutoTest in which the result is
+        :param auto_test_id: The id of the `AutoTest` in which the result is
             located.
         :param run_id: The id of run in which the result is located.
         :param result_id: The id of the result you want to get.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
 
-        :returns: The extended version of a <span
-                  data-role="class">.models.AutoTestResult</span>.
+        :returns: The extended version of a `AutoTestResult`.
         """
 
         url = (
@@ -664,8 +664,77 @@ class AutoTestService(t.Generic[_ClientT]):
             ),
         )
 
+    def create_output_html_proxy(
+        self: "AutoTestService[codegrade.client.AuthenticatedClient]",
+        json_body: t.Union[dict, list, "CreateOutputHtmlProxyAutoTestData"],
+        *,
+        auto_test_id: "int",
+        run_id: "int",
+        result_id: "int",
+        suite_id: "int",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "Proxy":
+        """Create a proxy to view the files of the given AT result through.
+
+        This allows you to view files of an AutoTest result (within a suite)
+        without authentication for a limited time.
+
+        :param json_body: The body of the request. See
+            :class:`.CreateOutputHtmlProxyAutoTestData` for information about
+            the possible fields. You can provide this data as a
+            :class:`.CreateOutputHtmlProxyAutoTestData` or as a dictionary.
+        :param auto_test_id: The id of the AutoTest in which the result is
+            located.
+        :param run_id: The id of run in which the result is located.
+        :param result_id: The id of the result from which you want to get the
+            files.
+        :param suite_id: The suite from which you want to proxy the output
+            files.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: The created proxy.
+        """
+
+        url = "/api/v1/auto_tests/{autoTestId}/runs/{runId}/results/{resultId}/suites/{suiteId}/proxy".format(
+            autoTestId=auto_test_id,
+            runId=run_id,
+            resultId=result_id,
+            suiteId=suite_id,
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.post(
+                url=url, json=utils.to_dict(json_body), params=params
+            )
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.proxy import Proxy
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                parsers.ParserFor.make(Proxy)
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
     def get_result_by_submission(
-        self: "AutoTestService[AuthenticatedClient]",
+        self: "AutoTestService[codegrade.client.AuthenticatedClient]",
         *,
         auto_test_id: "int",
         run_id: "int",
@@ -674,16 +743,17 @@ class AutoTestService(t.Generic[_ClientT]):
             str, t.Union[str, bool, int, float]
         ] = None,
     ) -> "ExtendedAutoTestResult":
-        """Get the AutoTest result for a submission.
+        """Get the `AutoTest` result for a submission.
 
-        :param auto_test_id: The id of the AutoTest in which to get the result.
-        :param run_id: The id of the AutoTestRun in which to get the result.
+        :param auto_test_id: The id of the `AutoTest` in which to get the
+            result.
+        :param run_id: The id of the `AutoTestRun` in which to get the result.
         :param submission_id: The id of the submission from which you want to
             get the result.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
 
-        :returns: The AutoTest result for the given data.
+        :returns: The `AutoTest` result for the given data.
         """
 
         url = "/api/v1/auto_tests/{autoTestId}/runs/{runId}/submissions/{submissionId}/result".format(
@@ -719,7 +789,7 @@ class AutoTestService(t.Generic[_ClientT]):
         )
 
     def get_results_by_user(
-        self: "AutoTestService[AuthenticatedClient]",
+        self: "AutoTestService[codegrade.client.AuthenticatedClient]",
         *,
         auto_test_id: "int",
         run_id: "int",
@@ -728,20 +798,20 @@ class AutoTestService(t.Generic[_ClientT]):
             str, t.Union[str, bool, int, float]
         ] = None,
     ) -> "t.Sequence[AutoTestResult]":
-        """Get all AutoTest results for a given user.
+        """Get all `AutoTest` results for a given user.
 
         If you don't have permission to see the results of the requested user
         an empty list will be returned.
 
-        :param auto_test_id: The id of the AutoTest in which to get the
+        :param auto_test_id: The id of the `AutoTest` in which to get the
             results.
-        :param run_id: The id of the AutoTestRun in which to get the results.
+        :param run_id: The id of the `AutoTestRun` in which to get the results.
         :param user_id: The id of the user of which we should get the results.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
 
-        :returns: The list of AutoTest results for the given user, sorted from
-                  oldest to latest.
+        :returns: The list of `AutoTest` results for the given user, sorted
+                  from oldest to latest.
         """
 
         url = "/api/v1/auto_tests/{autoTestId}/runs/{runId}/users/{userId}/results/".format(
@@ -775,7 +845,7 @@ class AutoTestService(t.Generic[_ClientT]):
         )
 
     def get_attachment(
-        self: "AutoTestService[AuthenticatedClient]",
+        self: "AutoTestService[codegrade.client.AuthenticatedClient]",
         *,
         auto_test_id: "int",
         run_id: "int",
@@ -784,9 +854,9 @@ class AutoTestService(t.Generic[_ClientT]):
             str, t.Union[str, bool, int, float]
         ] = None,
     ) -> "bytes":
-        """Get the attachment of an AutoTest step.
+        """Get the attachment of an `AutoTest` step.
 
-        :param auto_test_id: The id of the AutoTest in which the result is
+        :param auto_test_id: The id of the `AutoTest` in which the result is
             located.
         :param run_id: The id of run in which the result is located.
         :param step_result_id: The id of the step result of which you want the
@@ -826,7 +896,7 @@ class AutoTestService(t.Generic[_ClientT]):
         )
 
     def get_fixture(
-        self: "AutoTestService[AuthenticatedClient]",
+        self: "AutoTestService[codegrade.client.AuthenticatedClient]",
         *,
         auto_test_id: "int",
         fixture_id: "int",
@@ -836,7 +906,7 @@ class AutoTestService(t.Generic[_ClientT]):
     ) -> "bytes":
         """Get the contents of the given `AutoTestFixture`.
 
-        :param auto_test_id: The AutoTest this fixture is linked to.
+        :param auto_test_id: The `AutoTest` this fixture is linked to.
         :param fixture_id: The id of the fixture which you want the content.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
@@ -873,7 +943,7 @@ class AutoTestService(t.Generic[_ClientT]):
         )
 
     def get_not_started_results(
-        self: "AutoTestService[AuthenticatedClient]",
+        self: "AutoTestService[codegrade.client.AuthenticatedClient]",
         *,
         offset: "int" = 0,
         limit: "int" = 50,
@@ -882,7 +952,7 @@ class AutoTestService(t.Generic[_ClientT]):
             str, t.Union[str, bool, int, float]
         ] = None,
     ) -> "AllAutoTestResults":
-        """Get all AutoTest results on this instance.
+        """Get all `AutoTest` results on this instance.
 
         :param offset: First non started result to get.
         :param limit: Amount of non started results to get.
@@ -929,7 +999,7 @@ class AutoTestService(t.Generic[_ClientT]):
         )
 
     def hide_fixture(
-        self: "AutoTestService[AuthenticatedClient]",
+        self: "AutoTestService[codegrade.client.AuthenticatedClient]",
         *,
         auto_test_id: "int",
         fixture_id: "int",
@@ -942,7 +1012,7 @@ class AutoTestService(t.Generic[_ClientT]):
         Doing a `POST` request to this route will hide the fixture, doing a
         `DELETE` request to this route will set `hidden` to `False`.
 
-        :param auto_test_id: The AutoTest this fixture is linked to.
+        :param auto_test_id: The `AutoTest` this fixture is linked to.
         :param fixture_id: The fixture which you to hide or show.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
@@ -979,7 +1049,7 @@ class AutoTestService(t.Generic[_ClientT]):
         )
 
     def show_fixture(
-        self: "AutoTestService[AuthenticatedClient]",
+        self: "AutoTestService[codegrade.client.AuthenticatedClient]",
         *,
         auto_test_id: "int",
         fixture_id: "int",
@@ -992,7 +1062,7 @@ class AutoTestService(t.Generic[_ClientT]):
         Doing a `POST` request to this route will hide the fixture, doing a
         `DELETE` request to this route will set `hidden` to `False`.
 
-        :param auto_test_id: The AutoTest this fixture is linked to.
+        :param auto_test_id: The `AutoTest` this fixture is linked to.
         :param fixture_id: The fixture which you to hide or show.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
@@ -1029,7 +1099,7 @@ class AutoTestService(t.Generic[_ClientT]):
         )
 
     def restart_result(
-        self: "AutoTestService[AuthenticatedClient]",
+        self: "AutoTestService[codegrade.client.AuthenticatedClient]",
         *,
         auto_test_id: "int",
         run_id: "int",
@@ -1038,17 +1108,16 @@ class AutoTestService(t.Generic[_ClientT]):
             str, t.Union[str, bool, int, float]
         ] = None,
     ) -> "ExtendedAutoTestResult":
-        """Restart an AutoTest result.
+        """Restart an `AutoTest` result.
 
-        :param auto_test_id: The id of the AutoTest in which the result is
+        :param auto_test_id: The id of the `AutoTest` in which the result is
             located.
         :param run_id: The id of run in which the result is located.
         :param result_id: The id of the result you want to restart.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
 
-        :returns: The extended version of a <span
-                  data-role="class">.models.AutoTestResult</span>.
+        :returns: The extended version of a `AutoTestResult`.
         """
 
         url = "/api/v1/auto_tests/{autoTestId}/runs/{runId}/results/{resultId}/restart".format(
@@ -1084,7 +1153,7 @@ class AutoTestService(t.Generic[_ClientT]):
         )
 
     def start_run(
-        self: "AutoTestService[AuthenticatedClient]",
+        self: "AutoTestService[codegrade.client.AuthenticatedClient]",
         *,
         auto_test_id: "int",
         extra_parameters: t.Mapping[
@@ -1093,13 +1162,13 @@ class AutoTestService(t.Generic[_ClientT]):
     ) -> "t.Union[ExtendedAutoTestRun, t.Mapping[str, t.Literal['']]]":
         """Start a run for the given `AutoTest`.
 
-        :param auto_test_id: The id of the AutoTest for which you want to start
-            a run.
+        :param auto_test_id: The id of the `AutoTest` for which you want to
+            start a run.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
 
         :returns: The started run or a empty mapping if you do not have
-                  permission to see AutoTest runs.
+                  permission to see `AutoTest` runs.
         """
 
         url = "/api/v1/auto_tests/{autoTestId}/runs/".format(
@@ -1136,7 +1205,7 @@ class AutoTestService(t.Generic[_ClientT]):
         )
 
     def update_suite(
-        self: "AutoTestService[AuthenticatedClient]",
+        self: "AutoTestService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[dict, list, "UpdateSuiteAutoTestData"],
         *,
         auto_test_id: "int",
@@ -1148,20 +1217,17 @@ class AutoTestService(t.Generic[_ClientT]):
         """Update or create a `AutoTestSuite` (also known as category)
 
         :param json_body: The body of the request. See
-            :model:`.UpdateSuiteAutoTestData` for information about the
+            :class:`.UpdateSuiteAutoTestData` for information about the
             possible fields. You can provide this data as a
-            :model:`.UpdateSuiteAutoTestData` or as a dictionary.
-        :param auto_test_id: The id of the <span
-            data-role="class">.models.AutoTest</span> in which this suite
-            should be created.
-        :param set_id: The id the <span
-            data-role="class">.models.AutoTestSet</span> in which this suite
+            :class:`.UpdateSuiteAutoTestData` or as a dictionary.
+        :param auto_test_id: The id of the `AutoTest` in which this suite
             should be created.
+        :param set_id: The id the `AutoTestSet` in which this suite should be
+            created.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
 
-        :returns: The just updated or created <span
-                  data-role="class">.models.AutoTestSuite</span>.
+        :returns: The just updated or created `AutoTestSuite`.
         """
 
         url = "/api/v1/auto_tests/{autoTestId}/sets/{setId}/suites/".format(
