@@ -2,21 +2,28 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import os
 import typing as t
 
 import cg_request_args as rqa
 from cg_maybe import Maybe, Nothing
+from cg_maybe.utils import maybe_from_nullable
 
 from .. import parsers, utils
 
-if t.TYPE_CHECKING:
-    from ..client import AuthenticatedClient, _BaseClient
-    from ..models.any_error import AnyError
+if t.TYPE_CHECKING or os.getenv("CG_EAGERIMPORT", False):
+    import codegrade
+
     from ..models.assignment import Assignment
     from ..models.change_user_role_course_data import ChangeUserRoleCourseData
     from ..models.course_perm_map import CoursePermMap
     from ..models.course_price import CoursePrice
+    from ..models.course_register_response import CourseRegisterResponse
     from ..models.course_registration_link import CourseRegistrationLink
+    from ..models.course_role import CourseRole
+    from ..models.course_role_as_json_with_perms import (
+        CourseRoleAsJSONWithPerms,
+    )
     from ..models.course_snippet import CourseSnippet
     from ..models.create_assignment_course_data import (
         CreateAssignmentCourseData,
@@ -26,6 +33,9 @@ if t.TYPE_CHECKING:
     from ..models.create_snippet_course_data import CreateSnippetCourseData
     from ..models.email_users_course_data import EmailUsersCourseData
     from ..models.extended_course import ExtendedCourse
+    from ..models.extended_course_registration_link import (
+        ExtendedCourseRegistrationLink,
+    )
     from ..models.extended_work import ExtendedWork
     from ..models.group_set import GroupSet
     from ..models.import_into_course_data import ImportIntoCourseData
@@ -34,27 +44,35 @@ if t.TYPE_CHECKING:
     from ..models.patch_snippet_course_data import PatchSnippetCourseData
     from ..models.put_enroll_link_course_data import PutEnrollLinkCourseData
     from ..models.put_price_course_data import PutPriceCourseData
+    from ..models.register_user_with_link_course_data import (
+        RegisterUserWithLinkCourseData,
+    )
     from ..models.user import User
     from ..models.user_course import UserCourse
 
-_ClientT = t.TypeVar("_ClientT", bound="_BaseClient")
+
+_ClientT = t.TypeVar("_ClientT", bound="codegrade.client._BaseClient")
 
 
 class CourseService(t.Generic[_ClientT]):
     __slots__ = ("__client",)
 
-    def __init__(self, client: "_BaseClient") -> None:
+    def __init__(self, client: _ClientT) -> None:
         self.__client = client
 
     def get_all(
-        self: "CourseService[AuthenticatedClient]",
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
         *,
+        offset: Maybe["int"] = Nothing,
+        limit: Maybe["int"] = Nothing,
         extra_parameters: t.Mapping[
             str, t.Union[str, bool, int, float]
         ] = None,
     ) -> "t.Sequence[ExtendedCourse]":
         """Return all Course objects the current user is a member of.
 
+        :param offset: The index of the first course to be returned.
+        :param limit: The maximum amount of courses to return.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
 
@@ -62,7 +80,15 @@ class CourseService(t.Generic[_ClientT]):
         """
 
         url = "/api/v1/courses/"
-        params = extra_parameters or {}
+        params: t.Dict[str, t.Any] = {
+            **(extra_parameters or {}),
+        }
+        maybe_from_nullable(t.cast(t.Any, offset)).if_just(
+            lambda val: params.__setitem__("offset", val)
+        )
+        maybe_from_nullable(t.cast(t.Any, limit)).if_just(
+            lambda val: params.__setitem__("limit", val)
+        )
 
         with self.__client as client:
             resp = client.http.get(url=url, params=params)
@@ -90,7 +116,7 @@ class CourseService(t.Generic[_ClientT]):
         )
 
     def create(
-        self: "CourseService[AuthenticatedClient]",
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[dict, list, "CreateCourseData"],
         *,
         extra_parameters: t.Mapping[
@@ -100,8 +126,8 @@ class CourseService(t.Generic[_ClientT]):
         """Create a new course.
 
         :param json_body: The body of the request. See
-            :model:`.CreateCourseData` for information about the possible
-            fields. You can provide this data as a :model:`.CreateCourseData`
+            :class:`.CreateCourseData` for information about the possible
+            fields. You can provide this data as a :class:`.CreateCourseData`
             or as a dictionary.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
@@ -141,7 +167,7 @@ class CourseService(t.Generic[_ClientT]):
         )
 
     def create_snippet(
-        self: "CourseService[AuthenticatedClient]",
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[dict, list, "CreateSnippetCourseData"],
         *,
         course_id: "int",
@@ -149,13 +175,12 @@ class CourseService(t.Generic[_ClientT]):
             str, t.Union[str, bool, int, float]
         ] = None,
     ) -> "CourseSnippet":
-        """Add or modify a <span
-        data-role=\"class\">.models.CourseSnippet</span> by key.
+        """Add or modify a `CourseSnippet` by key.
 
         :param json_body: The body of the request. See
-            :model:`.CreateSnippetCourseData` for information about the
+            :class:`.CreateSnippetCourseData` for information about the
             possible fields. You can provide this data as a
-            :model:`.CreateSnippetCourseData` or as a dictionary.
+            :class:`.CreateSnippetCourseData` or as a dictionary.
         :param course_id: The id of the course in which you want to create a
             new snippet.
         :param extra_parameters: The extra query parameters you might want to
@@ -196,7 +221,7 @@ class CourseService(t.Generic[_ClientT]):
         )
 
     def get_group_sets(
-        self: "CourseService[AuthenticatedClient]",
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
         *,
         course_id: "int",
         extra_parameters: t.Mapping[
@@ -244,7 +269,7 @@ class CourseService(t.Generic[_ClientT]):
         )
 
     def create_group_set(
-        self: "CourseService[AuthenticatedClient]",
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[dict, list, "CreateGroupSetCourseData"],
         *,
         course_id: "int",
@@ -252,12 +277,12 @@ class CourseService(t.Generic[_ClientT]):
             str, t.Union[str, bool, int, float]
         ] = None,
     ) -> "GroupSet":
-        """Create or update a GroupSet in the given course id.
+        """Create or update a `GroupSet` in the given course id.
 
         :param json_body: The body of the request. See
-            :model:`.CreateGroupSetCourseData` for information about the
+            :class:`.CreateGroupSetCourseData` for information about the
             possible fields. You can provide this data as a
-            :model:`.CreateGroupSetCourseData` or as a dictionary.
+            :class:`.CreateGroupSetCourseData` or as a dictionary.
         :param course_id: The id of the course in which the group set should be
             created or updated. The course id of a group set cannot change.
         :param extra_parameters: The extra query parameters you might want to
@@ -298,8 +323,58 @@ class CourseService(t.Generic[_ClientT]):
             ),
         )
 
+    def get_assignments(
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
+        *,
+        course_id: "int",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "t.Sequence[Assignment]":
+        """Get all assignments of the given course.
+
+        The returned assignments are sorted by deadline.
+
+        :param course_id: The id of the course
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: A response containing the assignments of the given course
+                  sorted by deadline of the assignment
+        """
+
+        url = "/api/v1/courses/{courseId}/assignments/".format(
+            courseId=course_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.get(url=url, params=params)
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.assignment import Assignment
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                rqa.List(parsers.ParserFor.make(Assignment))
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
     def create_assignment(
-        self: "CourseService[AuthenticatedClient]",
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[dict, list, "CreateAssignmentCourseData"],
         *,
         course_id: "int",
@@ -310,9 +385,9 @@ class CourseService(t.Generic[_ClientT]):
         """Create a new course for the given assignment.
 
         :param json_body: The body of the request. See
-            :model:`.CreateAssignmentCourseData` for information about the
+            :class:`.CreateAssignmentCourseData` for information about the
             possible fields. You can provide this data as a
-            :model:`.CreateAssignmentCourseData` or as a dictionary.
+            :class:`.CreateAssignmentCourseData` or as a dictionary.
         :param course_id: The course to create an assignment in.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
@@ -353,7 +428,7 @@ class CourseService(t.Generic[_ClientT]):
         )
 
     def put_enroll_link(
-        self: "CourseService[AuthenticatedClient]",
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[dict, list, "PutEnrollLinkCourseData"],
         *,
         course_id: "int",
@@ -364,9 +439,9 @@ class CourseService(t.Generic[_ClientT]):
         """Create or edit an enroll link.
 
         :param json_body: The body of the request. See
-            :model:`.PutEnrollLinkCourseData` for information about the
+            :class:`.PutEnrollLinkCourseData` for information about the
             possible fields. You can provide this data as a
-            :model:`.PutEnrollLinkCourseData` or as a dictionary.
+            :class:`.PutEnrollLinkCourseData` or as a dictionary.
         :param course_id: The id of the course in which this link should enroll
             users.
         :param extra_parameters: The extra query parameters you might want to
@@ -408,7 +483,7 @@ class CourseService(t.Generic[_ClientT]):
         )
 
     def put_price(
-        self: "CourseService[AuthenticatedClient]",
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[dict, list, "PutPriceCourseData"],
         *,
         course_id: "int",
@@ -419,8 +494,8 @@ class CourseService(t.Generic[_ClientT]):
         """Update the price of the given course.
 
         :param json_body: The body of the request. See
-            :model:`.PutPriceCourseData` for information about the possible
-            fields. You can provide this data as a :model:`.PutPriceCourseData`
+            :class:`.PutPriceCourseData` for information about the possible
+            fields. You can provide this data as a :class:`.PutPriceCourseData`
             or as a dictionary.
         :param course_id: The id of the course for which you want to update the
             price.
@@ -461,7 +536,7 @@ class CourseService(t.Generic[_ClientT]):
         )
 
     def delete_price(
-        self: "CourseService[AuthenticatedClient]",
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
         *,
         course_id: "int",
         extra_parameters: t.Mapping[
@@ -503,7 +578,7 @@ class CourseService(t.Generic[_ClientT]):
         )
 
     def delete_snippet(
-        self: "CourseService[AuthenticatedClient]",
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
         *,
         course_id: "int",
         snippet_id: "int",
@@ -511,8 +586,7 @@ class CourseService(t.Generic[_ClientT]):
             str, t.Union[str, bool, int, float]
         ] = None,
     ) -> "None":
-        """Delete the <span data-role=\"class\">.models.CourseSnippet</span>
-        with the given id.
+        """Delete the `CourseSnippet` with the given id.
 
         :param course_id: The id of the course in which the snippet is located.
         :param snippet_id: The id of the snippet
@@ -549,7 +623,7 @@ class CourseService(t.Generic[_ClientT]):
         )
 
     def patch_snippet(
-        self: "CourseService[AuthenticatedClient]",
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[dict, list, "PatchSnippetCourseData"],
         *,
         course_id: "int",
@@ -558,13 +632,12 @@ class CourseService(t.Generic[_ClientT]):
             str, t.Union[str, bool, int, float]
         ] = None,
     ) -> "None":
-        """Modify the <span data-role=\"class\">.models.CourseSnippet</span>
-        with the given id.
+        """Modify the `CourseSnippet` with the given id.
 
         :param json_body: The body of the request. See
-            :model:`.PatchSnippetCourseData` for information about the possible
+            :class:`.PatchSnippetCourseData` for information about the possible
             fields. You can provide this data as a
-            :model:`.PatchSnippetCourseData` or as a dictionary.
+            :class:`.PatchSnippetCourseData` or as a dictionary.
         :param course_id: The id of the course in which the course snippet is
             saved.
         :param snippet_id: The id of the snippet to change.
@@ -603,7 +676,7 @@ class CourseService(t.Generic[_ClientT]):
         )
 
     def delete_role(
-        self: "CourseService[AuthenticatedClient]",
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
         *,
         course_id: "int",
         role_id: "int",
@@ -611,7 +684,7 @@ class CourseService(t.Generic[_ClientT]):
             str, t.Union[str, bool, int, float]
         ] = None,
     ) -> "None":
-        """Remove a CourseRole from the given Course.
+        """Remove a `CourseRole` from the given `Course`.
 
         :param course_id: The id of the course
         :param role_id: The id of the role you want to delete
@@ -647,27 +720,87 @@ class CourseService(t.Generic[_ClientT]):
             ),
         )
 
-    def get_all_users(
-        self: "CourseService[AuthenticatedClient]",
+    def get_course_roles(
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
         *,
         course_id: "int",
         extra_parameters: t.Mapping[
             str, t.Union[str, bool, int, float]
         ] = None,
-    ) -> "t.Union[t.Sequence[User], t.Sequence[UserCourse]]":
-        """Return a list of all <span data-role=\"class\">.models.User</span>
-        objects and their
+    ) -> "t.Union[t.Sequence[CourseRoleAsJSONWithPerms], t.Sequence[CourseRole]]":
+        """Get a list of all course roles in a given course.
 
-        :param course_id: The id of the course
+        :param course_id: The id of the course to get the roles for.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
 
-        :returns: A response containing the JSON serialized users and course
-                  roles
+        :returns: An array of all course roles for the given course.
+        """
+
+        url = "/api/v1/courses/{courseId}/roles/".format(courseId=course_id)
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.get(url=url, params=params)
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.course_role import CourseRole
+            from ..models.course_role_as_json_with_perms import (
+                CourseRoleAsJSONWithPerms,
+            )
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                parsers.make_union(
+                    rqa.List(
+                        parsers.ParserFor.make(CourseRoleAsJSONWithPerms)
+                    ),
+                    rqa.List(parsers.ParserFor.make(CourseRole)),
+                )
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
+    def get_all_users(
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
+        *,
+        course_id: "int",
+        q: Maybe["str"] = Nothing,
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "t.Union[t.Sequence[User], t.Sequence[UserCourse]]":
+        """Get all users and their role in a course.
+
+        :param course_id: The id of the course
+        :param q: Only retrieve users whose name or username matches this
+                  value. This will change the output to a list of users.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: All users in this course and their role. If you provided the
+                  `q` parameter only the user is returned, not their role.
         """
 
         url = "/api/v1/courses/{courseId}/users/".format(courseId=course_id)
-        params = extra_parameters or {}
+        params: t.Dict[str, t.Any] = {
+            **(extra_parameters or {}),
+        }
+        maybe_from_nullable(t.cast(t.Any, q)).if_just(
+            lambda val: params.__setitem__("q", val)
+        )
 
         with self.__client as client:
             resp = client.http.get(url=url, params=params)
@@ -699,7 +832,7 @@ class CourseService(t.Generic[_ClientT]):
         )
 
     def change_user_role(
-        self: "CourseService[AuthenticatedClient]",
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[dict, list, "ChangeUserRoleCourseData"],
         *,
         course_id: "int",
@@ -710,9 +843,9 @@ class CourseService(t.Generic[_ClientT]):
         """Set the `CourseRole` of a user in the given course.
 
         :param json_body: The body of the request. See
-            :model:`.ChangeUserRoleCourseData` for information about the
+            :class:`.ChangeUserRoleCourseData` for information about the
             possible fields. You can provide this data as a
-            :model:`.ChangeUserRoleCourseData` or as a dictionary.
+            :class:`.ChangeUserRoleCourseData` or as a dictionary.
         :param course_id: The id of the course in which you want to enroll a
             new user, or change the role of an existing user.
         :param extra_parameters: The extra query parameters you might want to
@@ -759,7 +892,7 @@ class CourseService(t.Generic[_ClientT]):
         )
 
     def get(
-        self: "CourseService[AuthenticatedClient]",
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
         *,
         course_id: "int",
         extra_parameters: t.Mapping[
@@ -804,7 +937,7 @@ class CourseService(t.Generic[_ClientT]):
         )
 
     def patch(
-        self: "CourseService[AuthenticatedClient]",
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[dict, list, "PatchCourseData"],
         *,
         course_id: "int",
@@ -815,8 +948,8 @@ class CourseService(t.Generic[_ClientT]):
         """Update the given course with new values.
 
         :param json_body: The body of the request. See
-            :model:`.PatchCourseData` for information about the possible
-            fields. You can provide this data as a :model:`.PatchCourseData` or
+            :class:`.PatchCourseData` for information about the possible
+            fields. You can provide this data as a :class:`.PatchCourseData` or
             as a dictionary.
         :param course_id: The id of the course you want to update.
         :param extra_parameters: The extra query parameters you might want to
@@ -856,7 +989,7 @@ class CourseService(t.Generic[_ClientT]):
         )
 
     def get_snippets(
-        self: "CourseService[AuthenticatedClient]",
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
         *,
         course_id: "int",
         extra_parameters: t.Mapping[
@@ -902,7 +1035,7 @@ class CourseService(t.Generic[_ClientT]):
         )
 
     def get_permissions(
-        self: "CourseService[AuthenticatedClient]",
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
         *,
         course_id: "int",
         extra_parameters: t.Mapping[
@@ -955,8 +1088,64 @@ class CourseService(t.Generic[_ClientT]):
             ),
         )
 
+    def get_registration_link(
+        self,
+        *,
+        course_id: "int",
+        link_id: "str",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "ExtendedCourseRegistrationLink":
+        """Get a registration link.
+
+        This route can be used without logging in, i.e. you don't have to be
+        enrolled in the course to use this route. This route will not work for
+        expired registration links.
+
+        :param course_id: The id of the course to which the registration link
+            is connected.
+        :param link_id: The id of the registration link.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: The specified registration link.
+        """
+
+        url = "/api/v1/courses/{courseId}/registration_links/{linkId}".format(
+            courseId=course_id, linkId=link_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.get(url=url, params=params)
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.extended_course_registration_link import (
+                ExtendedCourseRegistrationLink,
+            )
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                parsers.ParserFor.make(ExtendedCourseRegistrationLink)
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
     def get_submissions_by_user(
-        self: "CourseService[AuthenticatedClient]",
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
         *,
         course_id: "int",
         user_id: "int",
@@ -1022,7 +1211,7 @@ class CourseService(t.Generic[_ClientT]):
         )
 
     def import_into(
-        self: "CourseService[AuthenticatedClient]",
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[dict, list, "ImportIntoCourseData"],
         *,
         into_course_id: "int",
@@ -1033,9 +1222,9 @@ class CourseService(t.Generic[_ClientT]):
         """Copy a course into another course.
 
         :param json_body: The body of the request. See
-            :model:`.ImportIntoCourseData` for information about the possible
+            :class:`.ImportIntoCourseData` for information about the possible
             fields. You can provide this data as a
-            :model:`.ImportIntoCourseData` or as a dictionary.
+            :class:`.ImportIntoCourseData` or as a dictionary.
         :param into_course_id: The course you want to import into.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
@@ -1076,8 +1265,66 @@ class CourseService(t.Generic[_ClientT]):
             ),
         )
 
+    def register_user_with_link(
+        self,
+        json_body: t.Union[dict, list, "RegisterUserWithLinkCourseData"],
+        *,
+        course_id: "int",
+        link_id: "str",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "CourseRegisterResponse":
+        """Register as a new user, and directly enroll in a course.
+
+        :param json_body: The body of the request. See
+            :class:`.RegisterUserWithLinkCourseData` for information about the
+            possible fields. You can provide this data as a
+            :class:`.RegisterUserWithLinkCourseData` or as a dictionary.
+        :param course_id: The id of the course to which the registration link
+            is connected.
+        :param link_id: The id of the registration link.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: The access token that the created user can use to log in.
+        """
+
+        url = (
+            "/api/v1/courses/{courseId}/registration_links/{linkId}/user"
+            .format(courseId=course_id, linkId=link_id)
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.post(
+                url=url, json=utils.to_dict(json_body), params=params
+            )
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.course_register_response import CourseRegisterResponse
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                parsers.ParserFor.make(CourseRegisterResponse)
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
     def email_users(
-        self: "CourseService[AuthenticatedClient]",
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[dict, list, "EmailUsersCourseData"],
         *,
         course_id: "int",
@@ -1088,9 +1335,9 @@ class CourseService(t.Generic[_ClientT]):
         """Sent the authors in this course an email.
 
         :param json_body: The body of the request. See
-            :model:`.EmailUsersCourseData` for information about the possible
+            :class:`.EmailUsersCourseData` for information about the possible
             fields. You can provide this data as a
-            :model:`.EmailUsersCourseData` or as a dictionary.
+            :class:`.EmailUsersCourseData` or as a dictionary.
         :param course_id: The id of the course in which you want to send the
             emails.
         :param extra_parameters: The extra query parameters you might want to
