@@ -2,6 +2,7 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import os
 import typing as t
 
 import cg_request_args as rqa
@@ -9,9 +10,10 @@ from cg_maybe import Maybe, Nothing
 
 from .. import parsers, utils
 
-if t.TYPE_CHECKING:
-    from ..client import AuthenticatedClient, _BaseClient
-    from ..models.any_error import AnyError
+if t.TYPE_CHECKING or os.getenv("CG_EAGERIMPORT", False):
+    import codegrade
+
+    from ..models.create_proxy_submission_data import CreateProxySubmissionData
     from ..models.extended_work import ExtendedWork
     from ..models.feedback_with_replies import FeedbackWithReplies
     from ..models.feedback_without_replies import FeedbackWithoutReplies
@@ -22,254 +24,64 @@ if t.TYPE_CHECKING:
         PatchRubricResultSubmissionData,
     )
     from ..models.patch_submission_data import PatchSubmissionData
+    from ..models.proxy import Proxy
+    from ..models.root_file_trees_json import RootFileTreesJSON
     from ..models.work_rubric_result_as_json import WorkRubricResultAsJSON
 
-_ClientT = t.TypeVar("_ClientT", bound="_BaseClient")
+
+_ClientT = t.TypeVar("_ClientT", bound="codegrade.client._BaseClient")
 
 
 class SubmissionService(t.Generic[_ClientT]):
     __slots__ = ("__client",)
 
-    def __init__(self, client: "_BaseClient") -> None:
+    def __init__(self, client: _ClientT) -> None:
         self.__client = client
 
-    def delete_grader(
-        self,
+    def create_proxy(
+        self: "SubmissionService[codegrade.client.AuthenticatedClient]",
+        json_body: t.Union[dict, list, "CreateProxySubmissionData"],
         *,
         submission_id: "int",
         extra_parameters: t.Mapping[
             str, t.Union[str, bool, int, float]
         ] = None,
-    ) -> "None":
-        """Change the assigned grader of the given submission.
+    ) -> "Proxy":
+        """Create a proxy to view the files of the given submission through.
 
-        :param submission_id: The id of the submission.
-        :param extra_parameters: The extra query parameters you might want to
-            add. By default no extra query parameters are added.
-
-        :returns: Empty response and a 204 status.
-        """
-
-        url = "/api/v1/submissions/{submissionId}/grader".format(
-            submissionId=submission_id
-        )
-        params = extra_parameters or {}
-
-        with self.__client as client:
-            resp = client.http.delete(url=url, params=params)
-        utils.log_warnings(resp)
-
-        if utils.response_code_matches(resp.status_code, 204):
-            # fmt: off
-            # fmt: on
-            return parsers.ConstantlyParser(None).try_parse(resp)
-
-        from ..models.any_error import AnyError
-
-        raise utils.get_error(
-            resp,
-            (
-                (
-                    (400, 409, 401, 403, 404, "5XX"),
-                    utils.unpack_union(AnyError),
-                ),
-            ),
-        )
-
-    def patch_grader(
-        self,
-        json_body: t.Union[dict, list, "PatchGraderSubmissionData"],
-        *,
-        submission_id: "int",
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
-        ] = None,
-    ) -> "None":
-        """Change the assigned grader of the given submission.
+        This allows you to view files of a submission without authentication
+        for a limited time.
 
         :param json_body: The body of the request. See
-            :model:`.PatchGraderSubmissionData` for information about the
+            :class:`.CreateProxySubmissionData` for information about the
             possible fields. You can provide this data as a
-            :model:`.PatchGraderSubmissionData` or as a dictionary.
-        :param submission_id: The id of the submission.
+            :class:`.CreateProxySubmissionData` or as a dictionary.
+        :param submission_id: The submission for which the proxy should be
+            created.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
 
-        :returns: Empty response and a 204 status.
+        :returns: The created proxy.
         """
 
-        url = "/api/v1/submissions/{submissionId}/grader".format(
+        url = "/api/v1/submissions/{submissionId}/proxy".format(
             submissionId=submission_id
         )
         params = extra_parameters or {}
 
         with self.__client as client:
-            resp = client.http.patch(
+            resp = client.http.post(
                 url=url, json=utils.to_dict(json_body), params=params
             )
         utils.log_warnings(resp)
 
-        if utils.response_code_matches(resp.status_code, 204):
-            # fmt: off
-            # fmt: on
-            return parsers.ConstantlyParser(None).try_parse(resp)
-
-        from ..models.any_error import AnyError
-
-        raise utils.get_error(
-            resp,
-            (
-                (
-                    (400, 409, 401, 403, 404, "5XX"),
-                    utils.unpack_union(AnyError),
-                ),
-            ),
-        )
-
-    def get_feedback(
-        self: "SubmissionService[AuthenticatedClient]",
-        *,
-        submission_id: "int",
-        with_replies: "bool" = False,
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
-        ] = None,
-    ) -> "t.Union[FeedbackWithoutReplies, FeedbackWithReplies]":
-        """Get all feedback for a submission
-
-        :param submission_id: The submission of which you want to get the
-            feedback.
-        :param with_replies: Do you want to include replies in with your
-            comments? Starting with version "O.1" the default value will change
-            to `True`.
-        :param extra_parameters: The extra query parameters you might want to
-            add. By default no extra query parameters are added.
-
-        :returns: The feedback of this submission.
-        """
-
-        url = "/api/v1/submissions/{submissionId}/feedbacks/".format(
-            submissionId=submission_id
-        )
-        params: t.Dict[str, t.Any] = {
-            **(extra_parameters or {}),
-            "with_replies": utils.to_dict(with_replies),
-        }
-
-        with self.__client as client:
-            resp = client.http.get(url=url, params=params)
-        utils.log_warnings(resp)
-
         if utils.response_code_matches(resp.status_code, 200):
             # fmt: off
-            from ..models.feedback_with_replies import FeedbackWithReplies
-            from ..models.feedback_without_replies import FeedbackWithoutReplies
+            from ..models.proxy import Proxy
 
             # fmt: on
             return parsers.JsonResponseParser(
-                parsers.make_union(
-                    parsers.ParserFor.make(FeedbackWithoutReplies),
-                    parsers.ParserFor.make(FeedbackWithReplies),
-                )
-            ).try_parse(resp)
-
-        from ..models.any_error import AnyError
-
-        raise utils.get_error(
-            resp,
-            (
-                (
-                    (400, 409, 401, 403, 404, "5XX"),
-                    utils.unpack_union(AnyError),
-                ),
-            ),
-        )
-
-    def get_grade_history(
-        self: "SubmissionService[AuthenticatedClient]",
-        *,
-        submission_id: "int",
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
-        ] = None,
-    ) -> "t.Sequence[GradeHistory]":
-        """Get the grade history for the given submission.
-
-        :param submission_id: The submission for which you want to get the
-            grade history.
-        :param extra_parameters: The extra query parameters you might want to
-            add. By default no extra query parameters are added.
-
-        :returns: All the `GradeHistory` objects, which describe the history of
-                  this grade.
-        """
-
-        url = "/api/v1/submissions/{submissionId}/grade_history/".format(
-            submissionId=submission_id
-        )
-        params = extra_parameters or {}
-
-        with self.__client as client:
-            resp = client.http.get(url=url, params=params)
-        utils.log_warnings(resp)
-
-        if utils.response_code_matches(resp.status_code, 200):
-            # fmt: off
-            from ..models.grade_history import GradeHistory
-
-            # fmt: on
-            return parsers.JsonResponseParser(
-                rqa.List(parsers.ParserFor.make(GradeHistory))
-            ).try_parse(resp)
-
-        from ..models.any_error import AnyError
-
-        raise utils.get_error(
-            resp,
-            (
-                (
-                    (400, 409, 401, 403, 404, "5XX"),
-                    utils.unpack_union(AnyError),
-                ),
-            ),
-        )
-
-    def get_rubric_result(
-        self: "SubmissionService[AuthenticatedClient]",
-        *,
-        submission_id: "int",
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
-        ] = None,
-    ) -> "WorkRubricResultAsJSON":
-        """Get the full rubric result of the given submission (work).
-
-        :param submission_id: The id of the submission
-        :param extra_parameters: The extra query parameters you might want to
-            add. By default no extra query parameters are added.
-
-        :returns: The rubric result of the given submission, which also
-                  contains the rubric.
-        """
-
-        url = "/api/v1/submissions/{submissionId}/rubrics/".format(
-            submissionId=submission_id
-        )
-        params = extra_parameters or {}
-
-        with self.__client as client:
-            resp = client.http.get(url=url, params=params)
-        utils.log_warnings(resp)
-
-        if utils.response_code_matches(resp.status_code, 200):
-            # fmt: off
-            from ..models.work_rubric_result_as_json import (
-                WorkRubricResultAsJSON,
-            )
-
-            # fmt: on
-            return parsers.JsonResponseParser(
-                parsers.ParserFor.make(WorkRubricResultAsJSON)
+                parsers.ParserFor.make(Proxy)
             ).try_parse(resp)
 
         from ..models.any_error import AnyError
@@ -285,7 +97,7 @@ class SubmissionService(t.Generic[_ClientT]):
         )
 
     def get(
-        self: "SubmissionService[AuthenticatedClient]",
+        self: "SubmissionService[codegrade.client.AuthenticatedClient]",
         *,
         submission_id: "int",
         type: "t.Literal['default', 'feedback', 'zip']" = "default",
@@ -350,8 +162,51 @@ class SubmissionService(t.Generic[_ClientT]):
             ),
         )
 
-    def patch(
+    def delete(
         self,
+        *,
+        submission_id: "int",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "None":
+        """Delete a submission and all its files.
+
+        :param submission_id: The submission to delete.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: Nothing
+        """
+
+        url = "/api/v1/submissions/{submissionId}".format(
+            submissionId=submission_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.delete(url=url, params=params)
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 204):
+            # fmt: off
+            # fmt: on
+            return parsers.ConstantlyParser(None).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
+    def patch(
+        self: "SubmissionService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[dict, list, "PatchSubmissionData"],
         *,
         submission_id: "int",
@@ -362,9 +217,9 @@ class SubmissionService(t.Generic[_ClientT]):
         """Update the given submission with new values.
 
         :param json_body: The body of the request. See
-            :model:`.PatchSubmissionData` for information about the possible
+            :class:`.PatchSubmissionData` for information about the possible
             fields. You can provide this data as a
-            :model:`.PatchSubmissionData` or as a dictionary.
+            :class:`.PatchSubmissionData` or as a dictionary.
         :param submission_id: The id of the submission.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
@@ -404,8 +259,308 @@ class SubmissionService(t.Generic[_ClientT]):
             ),
         )
 
-    def patch_rubric_result(
+    def delete_grader(
         self,
+        *,
+        submission_id: "int",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "None":
+        """Change the assigned grader of the given submission.
+
+        :param submission_id: The id of the submission.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: Empty response and a 204 status.
+        """
+
+        url = "/api/v1/submissions/{submissionId}/grader".format(
+            submissionId=submission_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.delete(url=url, params=params)
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 204):
+            # fmt: off
+            # fmt: on
+            return parsers.ConstantlyParser(None).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
+    def patch_grader(
+        self: "SubmissionService[codegrade.client.AuthenticatedClient]",
+        json_body: t.Union[dict, list, "PatchGraderSubmissionData"],
+        *,
+        submission_id: "int",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "None":
+        """Change the assigned grader of the given submission.
+
+        :param json_body: The body of the request. See
+            :class:`.PatchGraderSubmissionData` for information about the
+            possible fields. You can provide this data as a
+            :class:`.PatchGraderSubmissionData` or as a dictionary.
+        :param submission_id: The id of the submission.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: Empty response and a 204 status.
+        """
+
+        url = "/api/v1/submissions/{submissionId}/grader".format(
+            submissionId=submission_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.patch(
+                url=url, json=utils.to_dict(json_body), params=params
+            )
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 204):
+            # fmt: off
+            # fmt: on
+            return parsers.ConstantlyParser(None).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
+    def get_feedback(
+        self: "SubmissionService[codegrade.client.AuthenticatedClient]",
+        *,
+        submission_id: "int",
+        with_replies: "bool" = False,
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "t.Union[FeedbackWithReplies, FeedbackWithoutReplies]":
+        """Get all feedback for a submission
+
+        :param submission_id: The submission of which you want to get the
+            feedback.
+        :param with_replies: Do you want to include replies in with your
+            comments? Starting with version "O.1" the default value will change
+            to `True`.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: The feedback of this submission.
+        """
+
+        url = "/api/v1/submissions/{submissionId}/feedbacks/".format(
+            submissionId=submission_id
+        )
+        params: t.Dict[str, t.Any] = {
+            **(extra_parameters or {}),
+            "with_replies": utils.to_dict(with_replies),
+        }
+
+        with self.__client as client:
+            resp = client.http.get(url=url, params=params)
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.feedback_with_replies import FeedbackWithReplies
+            from ..models.feedback_without_replies import FeedbackWithoutReplies
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                parsers.make_union(
+                    parsers.ParserFor.make(FeedbackWithReplies),
+                    parsers.ParserFor.make(FeedbackWithoutReplies),
+                )
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
+    def get_grade_history(
+        self: "SubmissionService[codegrade.client.AuthenticatedClient]",
+        *,
+        submission_id: "int",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "t.Sequence[GradeHistory]":
+        """Get the grade history for the given submission.
+
+        :param submission_id: The submission for which you want to get the
+            grade history.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: All the `GradeHistory` objects, which describe the history of
+                  this grade.
+        """
+
+        url = "/api/v1/submissions/{submissionId}/grade_history/".format(
+            submissionId=submission_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.get(url=url, params=params)
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.grade_history import GradeHistory
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                rqa.List(parsers.ParserFor.make(GradeHistory))
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
+    def get_root_file_trees(
+        self: "SubmissionService[codegrade.client.AuthenticatedClient]",
+        *,
+        submission_id: "int",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "RootFileTreesJSON":
+        """Get all the file trees of a submission.
+
+        :param submission_id: The id of the submission of which you want to get
+            the file trees.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: The student and teacher file tree, from the base/root
+                  directory of the submission.
+        """
+
+        url = "/api/v1/submissions/{submissionId}/root_file_trees/".format(
+            submissionId=submission_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.get(url=url, params=params)
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.root_file_trees_json import RootFileTreesJSON
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                parsers.ParserFor.make(RootFileTreesJSON)
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
+    def get_rubric_result(
+        self: "SubmissionService[codegrade.client.AuthenticatedClient]",
+        *,
+        submission_id: "int",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "WorkRubricResultAsJSON":
+        """Get the full rubric result of the given submission (work).
+
+        :param submission_id: The id of the submission
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: The rubric result of the given submission, which also
+                  contains the rubric.
+        """
+
+        url = "/api/v1/submissions/{submissionId}/rubrics/".format(
+            submissionId=submission_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.get(url=url, params=params)
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.work_rubric_result_as_json import (
+                WorkRubricResultAsJSON,
+            )
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                parsers.ParserFor.make(WorkRubricResultAsJSON)
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
+    def patch_rubric_result(
+        self: "SubmissionService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[dict, list, "PatchRubricResultSubmissionData"],
         *,
         submission_id: "int",
@@ -417,9 +572,9 @@ class SubmissionService(t.Generic[_ClientT]):
         """Select the given rubric items for the given submission.
 
         :param json_body: The body of the request. See
-            :model:`.PatchRubricResultSubmissionData` for information about the
+            :class:`.PatchRubricResultSubmissionData` for information about the
             possible fields. You can provide this data as a
-            :model:`.PatchRubricResultSubmissionData` or as a dictionary.
+            :class:`.PatchRubricResultSubmissionData` or as a dictionary.
         :param submission_id: The submission to unselect the item for.
         :param copy_locked_items: Should we maintain the selected items in
             locked rubric rows.
