@@ -15,6 +15,8 @@ if t.TYPE_CHECKING or os.getenv("CG_EAGERIMPORT", False):
 
     from ..models.create_tenant_data import CreateTenantData
     from ..models.extended_tenant import ExtendedTenant
+    from ..models.partial_all_site_settings import PartialAllSiteSettings
+    from ..models.patch_settings_tenant_data import PatchSettingsTenantData
     from ..models.patch_tenant_data import PatchTenantData
     from ..models.put_price_tenant_data import PutPriceTenantData
     from ..models.tenant_price import TenantPrice
@@ -384,6 +386,114 @@ class TenantService(t.Generic[_ClientT]):
             ),
         )
 
+    def get_settings(
+        self,
+        *,
+        tenant_id: "str",
+        only_frontend: "bool" = False,
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "PartialAllSiteSettings":
+        """Get the settings for this tenant.
+
+        :param tenant_id: The tenant for which to get the settings.
+        :param only_frontend: Get only the frontend settings. When `True` the
+            returned mapping will contain all frontend settings, even those
+            that only have a global value.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: The settings for this tenant.
+        """
+
+        url = "/api/v1/tenants/{tenantId}/settings/".format(tenantId=tenant_id)
+        params: t.Dict[str, t.Any] = {
+            **(extra_parameters or {}),
+            "only_frontend": utils.to_dict(only_frontend),
+        }
+
+        with self.__client as client:
+            resp = client.http.get(url=url, params=params)
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.partial_all_site_settings import (
+                PartialAllSiteSettings,
+            )
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                parsers.ParserFor.make(PartialAllSiteSettings)
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
+    def patch_settings(
+        self: "TenantService[codegrade.client.AuthenticatedClient]",
+        json_body: t.Union[dict, list, "PatchSettingsTenantData"],
+        *,
+        tenant_id: "str",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "PartialAllSiteSettings":
+        """Update the settings for this tenant.
+
+        :param json_body: The body of the request. See
+            :class:`.PatchSettingsTenantData` for information about the
+            possible fields. You can provide this data as a
+            :class:`.PatchSettingsTenantData` or as a dictionary.
+        :param tenant_id: The tenant to update the settings for.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: The updated tenant settings.
+        """
+
+        url = "/api/v1/tenants/{tenantId}/settings/".format(tenantId=tenant_id)
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.patch(
+                url=url, json=utils.to_dict(json_body), params=params
+            )
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.partial_all_site_settings import (
+                PartialAllSiteSettings,
+            )
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                parsers.ParserFor.make(PartialAllSiteSettings)
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
     def get_stats(
         self: "TenantService[codegrade.client.AuthenticatedClient]",
         *,
