@@ -18,7 +18,7 @@ _DEFAULT_HOST = os.getenv("CG_HOST", "https://app.codegra.de")
 
 _BaseClientT = t.TypeVar("_BaseClientT", bound="_BaseClient")
 
-if t.TYPE_CHECKING:
+if t.TYPE_CHECKING or os.getenv("CG_EAGERIMPORT", False):
     from codegrade._api.about import AboutService as _AboutService
     from codegrade._api.assignment import (
         AssignmentService as _AssignmentService,
@@ -34,14 +34,21 @@ if t.TYPE_CHECKING:
         GitProviderService as _GitProviderService,
     )
     from codegrade._api.group import GroupService as _GroupService
+    from codegrade._api.group_set import GroupSetService as _GroupSetService
     from codegrade._api.login_link import LoginLinkService as _LoginLinkService
     from codegrade._api.lti import LTIService as _LTIService
+    from codegrade._api.notification import (
+        NotificationService as _NotificationService,
+    )
     from codegrade._api.oauth_provider import (
         OAuthProviderService as _OAuthProviderService,
     )
     from codegrade._api.permission import (
         PermissionService as _PermissionService,
     )
+    from codegrade._api.plagiarism import (
+        PlagiarismService as _PlagiarismService,
+    )
     from codegrade._api.site_settings import (
         SiteSettingsService as _SiteSettingsService,
     )
@@ -68,25 +75,28 @@ class _BaseClient:
     __slots__ = (
         "__about",
         "__assignment",
-        "__course",
-        "__group",
-        "__user",
-        "__git_provider",
         "__auto_test",
+        "__comment",
+        "__course",
+        "__course_price",
+        "__file",
+        "__git_provider",
+        "__group",
+        "__group_set",
+        "__login_link",
         "__lti",
-        "__tenant",
-        "__submission",
+        "__notification",
         "__oauth_provider",
         "__permission",
-        "__file",
-        "__login_link",
-        "__user_setting",
-        "__comment",
+        "__plagiarism",
         "__site_settings",
         "__snippet",
+        "__submission",
         "__task_result",
+        "__tenant",
         "__transaction",
-        "__course_price",
+        "__user",
+        "__user_setting",
         "__open_level",
         "__http",
         "base_url",
@@ -101,17 +111,22 @@ class _BaseClient:
         self.__assignment: t.Optional[
             "_AssignmentService[_BaseClientT]"
         ] = None
+        self.__auto_test: t.Optional["_AutoTestService[_BaseClientT]"] = None
+        self.__comment: t.Optional["_CommentService[_BaseClientT]"] = None
         self.__course: t.Optional["_CourseService[_BaseClientT]"] = None
-        self.__group: t.Optional["_GroupService[_BaseClientT]"] = None
-        self.__user: t.Optional["_UserService[_BaseClientT]"] = None
+        self.__course_price: t.Optional[
+            "_CoursePriceService[_BaseClientT]"
+        ] = None
+        self.__file: t.Optional["_FileService[_BaseClientT]"] = None
         self.__git_provider: t.Optional[
             "_GitProviderService[_BaseClientT]"
         ] = None
-        self.__auto_test: t.Optional["_AutoTestService[_BaseClientT]"] = None
+        self.__group: t.Optional["_GroupService[_BaseClientT]"] = None
+        self.__group_set: t.Optional["_GroupSetService[_BaseClientT]"] = None
+        self.__login_link: t.Optional["_LoginLinkService[_BaseClientT]"] = None
         self.__lti: t.Optional["_LTIService[_BaseClientT]"] = None
-        self.__tenant: t.Optional["_TenantService[_BaseClientT]"] = None
-        self.__submission: t.Optional[
-            "_SubmissionService[_BaseClientT]"
+        self.__notification: t.Optional[
+            "_NotificationService[_BaseClientT]"
         ] = None
         self.__oauth_provider: t.Optional[
             "_OAuthProviderService[_BaseClientT]"
@@ -119,24 +134,26 @@ class _BaseClient:
         self.__permission: t.Optional[
             "_PermissionService[_BaseClientT]"
         ] = None
-        self.__file: t.Optional["_FileService[_BaseClientT]"] = None
-        self.__login_link: t.Optional["_LoginLinkService[_BaseClientT]"] = None
-        self.__user_setting: t.Optional[
-            "_UserSettingService[_BaseClientT]"
+        self.__plagiarism: t.Optional[
+            "_PlagiarismService[_BaseClientT]"
         ] = None
-        self.__comment: t.Optional["_CommentService[_BaseClientT]"] = None
         self.__site_settings: t.Optional[
             "_SiteSettingsService[_BaseClientT]"
         ] = None
         self.__snippet: t.Optional["_SnippetService[_BaseClientT]"] = None
+        self.__submission: t.Optional[
+            "_SubmissionService[_BaseClientT]"
+        ] = None
         self.__task_result: t.Optional[
             "_TaskResultService[_BaseClientT]"
         ] = None
+        self.__tenant: t.Optional["_TenantService[_BaseClientT]"] = None
         self.__transaction: t.Optional[
             "_TransactionService[_BaseClientT]"
         ] = None
-        self.__course_price: t.Optional[
-            "_CoursePriceService[_BaseClientT]"
+        self.__user: t.Optional["_UserService[_BaseClientT]"] = None
+        self.__user_setting: t.Optional[
+            "_UserSettingService[_BaseClientT]"
         ] = None
         self.__http: t.Optional[httpx.Client] = None
 
@@ -173,6 +190,7 @@ class _BaseClient:
 
     @property
     def about(self: _BaseClientT) -> "_AboutService[_BaseClientT]":
+        """Get a :class:`.AboutService` to do requests concerning About."""
         if self.__about is None:
             import codegrade._api.about as m
 
@@ -181,56 +199,109 @@ class _BaseClient:
 
     @property
     def assignment(self: _BaseClientT) -> "_AssignmentService[_BaseClientT]":
+        """Get a :class:`.AssignmentService` to do requests concerning
+        Assignment.
+        """
         if self.__assignment is None:
             import codegrade._api.assignment as m
 
             self.__assignment = m.AssignmentService(self)
         return self.__assignment
 
-    @property
-    def course(self: _BaseClientT) -> "_CourseService[_BaseClientT]":
-        if self.__course is None:
-            import codegrade._api.course as m
-
-            self.__course = m.CourseService(self)
-        return self.__course
-
-    @property
-    def group(self: _BaseClientT) -> "_GroupService[_BaseClientT]":
-        if self.__group is None:
-            import codegrade._api.group as m
-
-            self.__group = m.GroupService(self)
-        return self.__group
-
-    @property
-    def user(self: _BaseClientT) -> "_UserService[_BaseClientT]":
-        if self.__user is None:
-            import codegrade._api.user as m
-
-            self.__user = m.UserService(self)
-        return self.__user
-
-    @property
-    def git_provider(
-        self: _BaseClientT,
-    ) -> "_GitProviderService[_BaseClientT]":
-        if self.__git_provider is None:
-            import codegrade._api.git_provider as m
-
-            self.__git_provider = m.GitProviderService(self)
-        return self.__git_provider
-
     @property
     def auto_test(self: _BaseClientT) -> "_AutoTestService[_BaseClientT]":
+        """Get a :class:`.AutoTestService` to do requests concerning AutoTest."""
         if self.__auto_test is None:
             import codegrade._api.auto_test as m
 
             self.__auto_test = m.AutoTestService(self)
         return self.__auto_test
 
+    @property
+    def comment(self: _BaseClientT) -> "_CommentService[_BaseClientT]":
+        """Get a :class:`.CommentService` to do requests concerning Comment."""
+        if self.__comment is None:
+            import codegrade._api.comment as m
+
+            self.__comment = m.CommentService(self)
+        return self.__comment
+
+    @property
+    def course(self: _BaseClientT) -> "_CourseService[_BaseClientT]":
+        """Get a :class:`.CourseService` to do requests concerning Course."""
+        if self.__course is None:
+            import codegrade._api.course as m
+
+            self.__course = m.CourseService(self)
+        return self.__course
+
+    @property
+    def course_price(
+        self: _BaseClientT,
+    ) -> "_CoursePriceService[_BaseClientT]":
+        """Get a :class:`.CoursePriceService` to do requests concerning
+        CoursePrice.
+        """
+        if self.__course_price is None:
+            import codegrade._api.course_price as m
+
+            self.__course_price = m.CoursePriceService(self)
+        return self.__course_price
+
+    @property
+    def file(self: _BaseClientT) -> "_FileService[_BaseClientT]":
+        """Get a :class:`.FileService` to do requests concerning File."""
+        if self.__file is None:
+            import codegrade._api.file as m
+
+            self.__file = m.FileService(self)
+        return self.__file
+
+    @property
+    def git_provider(
+        self: _BaseClientT,
+    ) -> "_GitProviderService[_BaseClientT]":
+        """Get a :class:`.GitProviderService` to do requests concerning
+        GitProvider.
+        """
+        if self.__git_provider is None:
+            import codegrade._api.git_provider as m
+
+            self.__git_provider = m.GitProviderService(self)
+        return self.__git_provider
+
+    @property
+    def group(self: _BaseClientT) -> "_GroupService[_BaseClientT]":
+        """Get a :class:`.GroupService` to do requests concerning Group."""
+        if self.__group is None:
+            import codegrade._api.group as m
+
+            self.__group = m.GroupService(self)
+        return self.__group
+
+    @property
+    def group_set(self: _BaseClientT) -> "_GroupSetService[_BaseClientT]":
+        """Get a :class:`.GroupSetService` to do requests concerning GroupSet."""
+        if self.__group_set is None:
+            import codegrade._api.group_set as m
+
+            self.__group_set = m.GroupSetService(self)
+        return self.__group_set
+
+    @property
+    def login_link(self: _BaseClientT) -> "_LoginLinkService[_BaseClientT]":
+        """Get a :class:`.LoginLinkService` to do requests concerning
+        LoginLink.
+        """
+        if self.__login_link is None:
+            import codegrade._api.login_link as m
+
+            self.__login_link = m.LoginLinkService(self)
+        return self.__login_link
+
     @property
     def lti(self: _BaseClientT) -> "_LTIService[_BaseClientT]":
+        """Get a :class:`.LTIService` to do requests concerning LTI."""
         if self.__lti is None:
             import codegrade._api.lti as m
 
@@ -238,25 +309,25 @@ class _BaseClient:
         return self.__lti
 
     @property
-    def tenant(self: _BaseClientT) -> "_TenantService[_BaseClientT]":
-        if self.__tenant is None:
-            import codegrade._api.tenant as m
+    def notification(
+        self: _BaseClientT,
+    ) -> "_NotificationService[_BaseClientT]":
+        """Get a :class:`.NotificationService` to do requests concerning
+        Notification.
+        """
+        if self.__notification is None:
+            import codegrade._api.notification as m
 
-            self.__tenant = m.TenantService(self)
-        return self.__tenant
-
-    @property
-    def submission(self: _BaseClientT) -> "_SubmissionService[_BaseClientT]":
-        if self.__submission is None:
-            import codegrade._api.submission as m
-
-            self.__submission = m.SubmissionService(self)
-        return self.__submission
+            self.__notification = m.NotificationService(self)
+        return self.__notification
 
     @property
     def oauth_provider(
         self: _BaseClientT,
     ) -> "_OAuthProviderService[_BaseClientT]":
+        """Get a :class:`.OAuthProviderService` to do requests concerning
+        OAuthProvider.
+        """
         if self.__oauth_provider is None:
             import codegrade._api.oauth_provider as m
 
@@ -265,6 +336,9 @@ class _BaseClient:
 
     @property
     def permission(self: _BaseClientT) -> "_PermissionService[_BaseClientT]":
+        """Get a :class:`.PermissionService` to do requests concerning
+        Permission.
+        """
         if self.__permission is None:
             import codegrade._api.permission as m
 
@@ -272,43 +346,23 @@ class _BaseClient:
         return self.__permission
 
     @property
-    def file(self: _BaseClientT) -> "_FileService[_BaseClientT]":
-        if self.__file is None:
-            import codegrade._api.file as m
+    def plagiarism(self: _BaseClientT) -> "_PlagiarismService[_BaseClientT]":
+        """Get a :class:`.PlagiarismService` to do requests concerning
+        Plagiarism.
+        """
+        if self.__plagiarism is None:
+            import codegrade._api.plagiarism as m
 
-            self.__file = m.FileService(self)
-        return self.__file
-
-    @property
-    def login_link(self: _BaseClientT) -> "_LoginLinkService[_BaseClientT]":
-        if self.__login_link is None:
-            import codegrade._api.login_link as m
-
-            self.__login_link = m.LoginLinkService(self)
-        return self.__login_link
-
-    @property
-    def user_setting(
-        self: _BaseClientT,
-    ) -> "_UserSettingService[_BaseClientT]":
-        if self.__user_setting is None:
-            import codegrade._api.user_setting as m
-
-            self.__user_setting = m.UserSettingService(self)
-        return self.__user_setting
-
-    @property
-    def comment(self: _BaseClientT) -> "_CommentService[_BaseClientT]":
-        if self.__comment is None:
-            import codegrade._api.comment as m
-
-            self.__comment = m.CommentService(self)
-        return self.__comment
+            self.__plagiarism = m.PlagiarismService(self)
+        return self.__plagiarism
 
     @property
     def site_settings(
         self: _BaseClientT,
     ) -> "_SiteSettingsService[_BaseClientT]":
+        """Get a :class:`.SiteSettingsService` to do requests concerning
+        SiteSettings.
+        """
         if self.__site_settings is None:
             import codegrade._api.site_settings as m
 
@@ -317,22 +371,49 @@ class _BaseClient:
 
     @property
     def snippet(self: _BaseClientT) -> "_SnippetService[_BaseClientT]":
+        """Get a :class:`.SnippetService` to do requests concerning Snippet."""
         if self.__snippet is None:
             import codegrade._api.snippet as m
 
             self.__snippet = m.SnippetService(self)
         return self.__snippet
 
+    @property
+    def submission(self: _BaseClientT) -> "_SubmissionService[_BaseClientT]":
+        """Get a :class:`.SubmissionService` to do requests concerning
+        Submission.
+        """
+        if self.__submission is None:
+            import codegrade._api.submission as m
+
+            self.__submission = m.SubmissionService(self)
+        return self.__submission
+
     @property
     def task_result(self: _BaseClientT) -> "_TaskResultService[_BaseClientT]":
+        """Get a :class:`.TaskResultService` to do requests concerning
+        TaskResult.
+        """
         if self.__task_result is None:
             import codegrade._api.task_result as m
 
             self.__task_result = m.TaskResultService(self)
         return self.__task_result
 
+    @property
+    def tenant(self: _BaseClientT) -> "_TenantService[_BaseClientT]":
+        """Get a :class:`.TenantService` to do requests concerning Tenant."""
+        if self.__tenant is None:
+            import codegrade._api.tenant as m
+
+            self.__tenant = m.TenantService(self)
+        return self.__tenant
+
     @property
     def transaction(self: _BaseClientT) -> "_TransactionService[_BaseClientT]":
+        """Get a :class:`.TransactionService` to do requests concerning
+        Transaction.
+        """
         if self.__transaction is None:
             import codegrade._api.transaction as m
 
@@ -340,14 +421,26 @@ class _BaseClient:
         return self.__transaction
 
     @property
-    def course_price(
-        self: _BaseClientT,
-    ) -> "_CoursePriceService[_BaseClientT]":
-        if self.__course_price is None:
-            import codegrade._api.course_price as m
+    def user(self: _BaseClientT) -> "_UserService[_BaseClientT]":
+        """Get a :class:`.UserService` to do requests concerning User."""
+        if self.__user is None:
+            import codegrade._api.user as m
 
-            self.__course_price = m.CoursePriceService(self)
-        return self.__course_price
+            self.__user = m.UserService(self)
+        return self.__user
+
+    @property
+    def user_setting(
+        self: _BaseClientT,
+    ) -> "_UserSettingService[_BaseClientT]":
+        """Get a :class:`.UserSettingService` to do requests concerning
+        UserSetting.
+        """
+        if self.__user_setting is None:
+            import codegrade._api.user_setting as m
+
+            self.__user_setting = m.UserSettingService(self)
+        return self.__user_setting
 
 
 class Client(_BaseClient):
@@ -391,14 +484,17 @@ class AuthenticatedClient(_BaseClient):
         tenant: str = None,
         host: str = _DEFAULT_HOST,
     ) -> "AuthenticatedClient":
-        """Get an :model:`.AuthenticatedClient` by logging in with your
+        """Get an :class:`.AuthenticatedClient` by logging in with your
         username and password.
 
         .. code-block:: python
 
-        with AuthenticatedClient.get( username='my-username',
-        password=os.getenv('CG_PASS'), tenant='My University', ) as client:
-        print('Hi I am {}'.format(client.user.get().name)
+            with AuthenticatedClient.get(
+                username='my-username',
+                password=os.getenv('CG_PASS'),
+                tenant='My University',
+            ) as client:
+                print('Hi I am {}'.format(client.user.get().name)
 
         :param username: Your CodeGrade username.
         :param password: Your CodeGrade password, if you do not know your
@@ -464,7 +560,7 @@ class AuthenticatedClient(_BaseClient):
         *,
         check: bool = True,
     ) -> "AuthenticatedClient":
-        """Get an :model:`.AuthenticatedClient` by logging with an access
+        """Get an :class:`.AuthenticatedClient` by logging with an access
         token.
 
         :param token: The access token you want to use to login.
@@ -488,6 +584,11 @@ class AuthenticatedClient(_BaseClient):
 
     @classmethod
     def get_from_cli(cls) -> "AuthenticatedClient":
+        """Get an :class:`.AuthenticatedClient` by logging in through command
+        line interface.
+
+        :returns: A new ``AuthenticatedClient``.
+        """
         host = (
             maybe_input("Your instance", _DEFAULT_HOST)
             .map(cls._prepare_host)
