@@ -59,16 +59,34 @@ class AllSiteSettings(FrontendSiteSettings):
     #: users. This is also the maximum total size of submissions. Increasing
     #: this size might cause a hosting costs to increase.
     max_normal_upload_size: "int"
+    #: The maximum total size of files part of an editor submission in
+    #: dynamodb. This is not the same as MAX\_NORMAL\_UPLOAD\_SIZE. Increasing
+    #: this size might cause a hosting costs to increase.
+    max_dynamo_submission_size: "int"
     #: The maximum size of a single file uploaded by normal users. This limit
     #: is really here to prevent users from uploading extremely large files
     #: which can't really be downloaded/shown anyway.
     max_file_size: "int"
+    #: The maximum size of a single file's updates in dynamodb. This is not the
+    #: same as MAX\_FILE\_SIZE. This limit is to avoid having huge files stored
+    #: in dynamodb, as storage is expensive.
+    max_dynamo_file_size: "int"
+    #: The maximum size of a single update (CRDT) to a file in dynamodb. This
+    #: is not the same as MAX\_DYNAMO\_FILE\_SIZE, as it refers to a single
+    #: edit operation. This limit is to avoid having huge items stored in
+    #: dynamodb, as storage is expensive. If the CRDT exceeds the given size,
+    #: it will be uploaded to a S3 object.
+    max_document_update_size: "int"
     #: The time a login session is valid. After this amount of time a user will
     #: always need to re-authenticate.
     jwt_access_token_expires: "datetime.timedelta"
     #: The time a user has to download a file from the mirror storage, after
     #: this time the file will be deleted.
     max_mirror_file_age: "datetime.timedelta"
+    #: The maximum number of user settings stored per user.
+    max_user_setting_amount: "int"
+    #: Should a registration email be sent to new users upon registration.
+    send_registration_email: "bool"
 
     raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
@@ -189,6 +207,16 @@ class AllSiteSettings(FrontendSiteSettings):
                         " might cause a hosting costs to increase."
                     ),
                 ),
+                rqa.RequiredArgument(
+                    "MAX_DYNAMO_SUBMISSION_SIZE",
+                    rqa.SimpleValue.int,
+                    doc=(
+                        "The maximum total size of files part of an editor"
+                        " submission in dynamodb. This is not the same as"
+                        " MAX\\_NORMAL\\_UPLOAD\\_SIZE. Increasing this size"
+                        " might cause a hosting costs to increase."
+                    ),
+                ),
                 rqa.RequiredArgument(
                     "MAX_FILE_SIZE",
                     rqa.SimpleValue.int,
@@ -199,6 +227,29 @@ class AllSiteSettings(FrontendSiteSettings):
                         " really be downloaded/shown anyway."
                     ),
                 ),
+                rqa.RequiredArgument(
+                    "MAX_DYNAMO_FILE_SIZE",
+                    rqa.SimpleValue.int,
+                    doc=(
+                        "The maximum size of a single file's updates in"
+                        " dynamodb. This is not the same as MAX\\_FILE\\_SIZE."
+                        " This limit is to avoid having huge files stored in"
+                        " dynamodb, as storage is expensive."
+                    ),
+                ),
+                rqa.RequiredArgument(
+                    "MAX_DOCUMENT_UPDATE_SIZE",
+                    rqa.SimpleValue.int,
+                    doc=(
+                        "The maximum size of a single update (CRDT) to a file"
+                        " in dynamodb. This is not the same as"
+                        " MAX\\_DYNAMO\\_FILE\\_SIZE, as it refers to a single"
+                        " edit operation. This limit is to avoid having huge"
+                        " items stored in dynamodb, as storage is expensive."
+                        " If the CRDT exceeds the given size, it will be"
+                        " uploaded to a S3 object."
+                    ),
+                ),
                 rqa.RequiredArgument(
                     "JWT_ACCESS_TOKEN_EXPIRES",
                     rqa.RichValue.TimeDelta,
@@ -216,6 +267,19 @@ class AllSiteSettings(FrontendSiteSettings):
                         " deleted."
                     ),
                 ),
+                rqa.RequiredArgument(
+                    "MAX_USER_SETTING_AMOUNT",
+                    rqa.SimpleValue.int,
+                    doc="The maximum number of user settings stored per user.",
+                ),
+                rqa.RequiredArgument(
+                    "SEND_REGISTRATION_EMAIL",
+                    rqa.SimpleValue.bool,
+                    doc=(
+                        "Should a registration email be sent to new users upon"
+                        " registration."
+                    ),
+                ),
             )
         ).use_readable_describe(True)
     )
@@ -246,9 +310,16 @@ class AllSiteSettings(FrontendSiteSettings):
             "MAX_NUMBER_OF_FILES": to_dict(self.max_number_of_files),
             "MAX_LARGE_UPLOAD_SIZE": to_dict(self.max_large_upload_size),
             "MAX_NORMAL_UPLOAD_SIZE": to_dict(self.max_normal_upload_size),
+            "MAX_DYNAMO_SUBMISSION_SIZE": to_dict(
+                self.max_dynamo_submission_size
+            ),
             "MAX_FILE_SIZE": to_dict(self.max_file_size),
+            "MAX_DYNAMO_FILE_SIZE": to_dict(self.max_dynamo_file_size),
+            "MAX_DOCUMENT_UPDATE_SIZE": to_dict(self.max_document_update_size),
             "JWT_ACCESS_TOKEN_EXPIRES": to_dict(self.jwt_access_token_expires),
             "MAX_MIRROR_FILE_AGE": to_dict(self.max_mirror_file_age),
+            "MAX_USER_SETTING_AMOUNT": to_dict(self.max_user_setting_amount),
+            "SEND_REGISTRATION_EMAIL": to_dict(self.send_registration_email),
             "AUTO_TEST_MAX_TIME_COMMAND": to_dict(
                 self.auto_test_max_time_command
             ),
@@ -286,9 +357,6 @@ class AllSiteSettings(FrontendSiteSettings):
             "AUTO_TEST_MAX_PER_STUDENT_SETUP_TIME": to_dict(
                 self.auto_test_max_per_student_setup_time
             ),
-            "SERVER_TIME_DIFF_TOLERANCE": to_dict(
-                self.server_time_diff_tolerance
-            ),
             "ASSIGNMENT_DEFAULT_GRADING_SCALE": to_dict(
                 self.assignment_default_grading_scale
             ),
@@ -313,9 +381,33 @@ class AllSiteSettings(FrontendSiteSettings):
             "PEER_FEEDBACK_ENABLED": to_dict(self.peer_feedback_enabled),
             "AT_IMAGE_CACHING_ENABLED": to_dict(self.at_image_caching_enabled),
             "STUDENT_PAYMENT_ENABLED": to_dict(self.student_payment_enabled),
+            "EDITOR_ENABLED": to_dict(self.editor_enabled),
+            "SERVER_TIME_CORRECTION_ENABLED": to_dict(
+                self.server_time_correction_enabled
+            ),
+            "METRIC_GATHERING_ENABLED": to_dict(self.metric_gathering_enabled),
             "FEEDBACK_THREADS_INITIALLY_COLLAPSED": to_dict(
                 self.feedback_threads_initially_collapsed
             ),
+            "METRIC_GATHERING_TIME_INTERVAL": to_dict(
+                self.metric_gathering_time_interval
+            ),
+            "METRIC_GATHERING_EVENT_INTERVAL": to_dict(
+                self.metric_gathering_event_interval
+            ),
+            "METRIC_EVENT_BUFFER_SIZE": to_dict(self.metric_event_buffer_size),
+            "METRIC_EVALUATION_TIME_LIMIT": to_dict(
+                self.metric_evaluation_time_limit
+            ),
+            "METRIC_GATHERING_EXPRESSIONS": to_dict(
+                self.metric_gathering_expressions
+            ),
+            "SERVER_TIME_DIFF_TOLERANCE": to_dict(
+                self.server_time_diff_tolerance
+            ),
+            "SERVER_TIME_SYNC_INTERVAL": to_dict(
+                self.server_time_sync_interval
+            ),
         }
         return res
 
@@ -338,9 +430,14 @@ class AllSiteSettings(FrontendSiteSettings):
             max_number_of_files=parsed.MAX_NUMBER_OF_FILES,
             max_large_upload_size=parsed.MAX_LARGE_UPLOAD_SIZE,
             max_normal_upload_size=parsed.MAX_NORMAL_UPLOAD_SIZE,
+            max_dynamo_submission_size=parsed.MAX_DYNAMO_SUBMISSION_SIZE,
             max_file_size=parsed.MAX_FILE_SIZE,
+            max_dynamo_file_size=parsed.MAX_DYNAMO_FILE_SIZE,
+            max_document_update_size=parsed.MAX_DOCUMENT_UPDATE_SIZE,
             jwt_access_token_expires=parsed.JWT_ACCESS_TOKEN_EXPIRES,
             max_mirror_file_age=parsed.MAX_MIRROR_FILE_AGE,
+            max_user_setting_amount=parsed.MAX_USER_SETTING_AMOUNT,
+            send_registration_email=parsed.SEND_REGISTRATION_EMAIL,
             auto_test_max_time_command=parsed.AUTO_TEST_MAX_TIME_COMMAND,
             auto_test_io_test_message=parsed.AUTO_TEST_IO_TEST_MESSAGE,
             auto_test_io_test_sub_message=parsed.AUTO_TEST_IO_TEST_SUB_MESSAGE,
@@ -358,7 +455,6 @@ class AllSiteSettings(FrontendSiteSettings):
             max_plagiarism_matches=parsed.MAX_PLAGIARISM_MATCHES,
             auto_test_max_global_setup_time=parsed.AUTO_TEST_MAX_GLOBAL_SETUP_TIME,
             auto_test_max_per_student_setup_time=parsed.AUTO_TEST_MAX_PER_STUDENT_SETUP_TIME,
-            server_time_diff_tolerance=parsed.SERVER_TIME_DIFF_TOLERANCE,
             assignment_default_grading_scale=parsed.ASSIGNMENT_DEFAULT_GRADING_SCALE,
             blackboard_zip_upload_enabled=parsed.BLACKBOARD_ZIP_UPLOAD_ENABLED,
             rubrics_enabled=parsed.RUBRICS_ENABLED,
@@ -375,7 +471,17 @@ class AllSiteSettings(FrontendSiteSettings):
             peer_feedback_enabled=parsed.PEER_FEEDBACK_ENABLED,
             at_image_caching_enabled=parsed.AT_IMAGE_CACHING_ENABLED,
             student_payment_enabled=parsed.STUDENT_PAYMENT_ENABLED,
+            editor_enabled=parsed.EDITOR_ENABLED,
+            server_time_correction_enabled=parsed.SERVER_TIME_CORRECTION_ENABLED,
+            metric_gathering_enabled=parsed.METRIC_GATHERING_ENABLED,
             feedback_threads_initially_collapsed=parsed.FEEDBACK_THREADS_INITIALLY_COLLAPSED,
+            metric_gathering_time_interval=parsed.METRIC_GATHERING_TIME_INTERVAL,
+            metric_gathering_event_interval=parsed.METRIC_GATHERING_EVENT_INTERVAL,
+            metric_event_buffer_size=parsed.METRIC_EVENT_BUFFER_SIZE,
+            metric_evaluation_time_limit=parsed.METRIC_EVALUATION_TIME_LIMIT,
+            metric_gathering_expressions=parsed.METRIC_GATHERING_EXPRESSIONS,
+            server_time_diff_tolerance=parsed.SERVER_TIME_DIFF_TOLERANCE,
+            server_time_sync_interval=parsed.SERVER_TIME_SYNC_INTERVAL,
         )
         res.raw_data = d
         return res
