@@ -11,6 +11,9 @@ from httpx import Response
 
 from ..parsers import ParserFor, make_union
 from ..utils import to_dict
+from .auto_test_step_validation_exception import (
+    AutoTestStepValidationException,
+)
 from .base_error import BaseError
 from .disabled_setting_exception import DisabledSettingException
 from .failed_to_send_email_exception import FailedToSendEmailException
@@ -32,10 +35,11 @@ AnyError = t.Union[
     DisabledSettingException,
     WeakPasswordException,
     ParseAPIException,
+    InvalidIOCasesException,
     PermissionException,
     FailedToSendEmailException,
     GroupNotReadyForSubmissionException,
-    InvalidIOCasesException,
+    AutoTestStepValidationException,
     InvalidGroupException,
     MissingCookieError,
     IgnoredFilesException,
@@ -49,10 +53,11 @@ AnyErrorParser = rqa.Lazy(
         ParserFor.make(DisabledSettingException),
         ParserFor.make(WeakPasswordException),
         ParserFor.make(ParseAPIException),
+        ParserFor.make(InvalidIOCasesException),
         ParserFor.make(PermissionException),
         ParserFor.make(FailedToSendEmailException),
         ParserFor.make(GroupNotReadyForSubmissionException),
-        ParserFor.make(InvalidIOCasesException),
+        ParserFor.make(AutoTestStepValidationException),
         ParserFor.make(InvalidGroupException),
         ParserFor.make(MissingCookieError),
         ParserFor.make(IgnoredFilesException),
