@@ -2,6 +2,7 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+
 import typing as t
 from dataclasses import dataclass, field
 
@@ -87,3 +88,12 @@ class BaseLTI1p1Provider(BaseLTIProvider):
         )
         res.raw_data = d
         return res
+
+
+import os
+
+if os.getenv("CG_GENERATING_DOCS", "False").lower() in ("", "true"):
+    # fmt: off
+    import datetime
+
+    # fmt: on
