@@ -65,10 +65,6 @@ class FrontendSiteSettings:
     #: may take. If it takes longer than this it will be killed and the result
     #: of the student will be in the state "timed-out"
     auto_test_max_per_student_setup_time: "datetime.timedelta"
-    #: The maximum amount of difference between the server time and the local
-    #: time before we consider the local time to be out of sync with our
-    #: servers.
-    server_time_diff_tolerance: "datetime.timedelta"
     #: The default value for the grading scale of new assignments.
     assignment_default_grading_scale: "t.Literal['percentage', 'points']"
     #: If enabled teachers are allowed to bulk upload submissions (and create
@@ -113,8 +109,36 @@ class FrontendSiteSettings:
     #: to enable this deploy config needs to be updated, so don't just enable
     #: it.
     student_payment_enabled: "bool"
+    #: Can students submit using the online editor.
+    editor_enabled: "bool"
+    #: Whether the time as detected locally on a user's computer is corrected
+    #: by the difference with the time as reported by the backend server.
+    server_time_correction_enabled: "bool"
+    #: Whether the gathering of user behaviour events and subsequent metrics
+    #: enabled.
+    metric_gathering_enabled: "bool"
     #: Feedback threads will start collapsed from this depth of the tree.
     feedback_threads_initially_collapsed: "int"
+    #: The time interval between gathering of metrics.
+    metric_gathering_time_interval: "datetime.timedelta"
+    #: The percentage of the event buffer fill that causes a gathering of
+    #: metrics.
+    metric_gathering_event_interval: "int"
+    #: The size of the circular buffer containing the trace of user behaviour
+    #: events.
+    metric_event_buffer_size: "int"
+    #: The size of the circular buffer containing the trace of user behaviour
+    #: events.
+    metric_evaluation_time_limit: "datetime.timedelta"
+    #: Expressions for the metrics we want to measure.
+    metric_gathering_expressions: "t.Mapping[str, str]"
+    #: The maximum amount of difference between the server time and the local
+    #: time before we consider the local time to be out of sync with our
+    #: servers.
+    server_time_diff_tolerance: "datetime.timedelta"
+    #: The interval at which we request the server time in case it is out of
+    #: sync with the local time.
+    server_time_sync_interval: "datetime.timedelta"
 
     raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
@@ -244,15 +268,6 @@ class FrontendSiteSettings:
                     ' will be in the state "timed-out"'
                 ),
             ),
-            rqa.RequiredArgument(
-                "SERVER_TIME_DIFF_TOLERANCE",
-                rqa.RichValue.TimeDelta,
-                doc=(
-                    "The maximum amount of difference between the server time"
-                    " and the local time before we consider the local time to"
-                    " be out of sync with our servers."
-                ),
-            ),
             rqa.RequiredArgument(
                 "ASSIGNMENT_DEFAULT_GRADING_SCALE",
                 rqa.StringEnum("percentage", "points"),
@@ -366,6 +381,28 @@ class FrontendSiteSettings:
                     " be updated, so don't just enable it."
                 ),
             ),
+            rqa.RequiredArgument(
+                "EDITOR_ENABLED",
+                rqa.SimpleValue.bool,
+                doc="Can students submit using the online editor.",
+            ),
+            rqa.RequiredArgument(
+                "SERVER_TIME_CORRECTION_ENABLED",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Whether the time as detected locally on a user's computer"
+                    " is corrected by the difference with the time as reported"
+                    " by the backend server."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "METRIC_GATHERING_ENABLED",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Whether the gathering of user behaviour events and"
+                    " subsequent metrics enabled."
+                ),
+            ),
             rqa.RequiredArgument(
                 "FEEDBACK_THREADS_INITIALLY_COLLAPSED",
                 rqa.SimpleValue.int,
@@ -374,6 +411,57 @@ class FrontendSiteSettings:
                     " the tree."
                 ),
             ),
+            rqa.RequiredArgument(
+                "METRIC_GATHERING_TIME_INTERVAL",
+                rqa.RichValue.TimeDelta,
+                doc="The time interval between gathering of metrics.",
+            ),
+            rqa.RequiredArgument(
+                "METRIC_GATHERING_EVENT_INTERVAL",
+                rqa.SimpleValue.int,
+                doc=(
+                    "The percentage of the event buffer fill that causes a"
+                    " gathering of metrics."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "METRIC_EVENT_BUFFER_SIZE",
+                rqa.SimpleValue.int,
+                doc=(
+                    "The size of the circular buffer containing the trace of"
+                    " user behaviour events."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "METRIC_EVALUATION_TIME_LIMIT",
+                rqa.RichValue.TimeDelta,
+                doc=(
+                    "The size of the circular buffer containing the trace of"
+                    " user behaviour events."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "METRIC_GATHERING_EXPRESSIONS",
+                rqa.LookupMapping(rqa.SimpleValue.str),
+                doc="Expressions for the metrics we want to measure.",
+            ),
+            rqa.RequiredArgument(
+                "SERVER_TIME_DIFF_TOLERANCE",
+                rqa.RichValue.TimeDelta,
+                doc=(
+                    "The maximum amount of difference between the server time"
+                    " and the local time before we consider the local time to"
+                    " be out of sync with our servers."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "SERVER_TIME_SYNC_INTERVAL",
+                rqa.RichValue.TimeDelta,
+                doc=(
+                    "The interval at which we request the server time in case"
+                    " it is out of sync with the local time."
+                ),
+            ),
         ).use_readable_describe(True)
     )
 
@@ -416,9 +504,6 @@ class FrontendSiteSettings:
             "AUTO_TEST_MAX_PER_STUDENT_SETUP_TIME": to_dict(
                 self.auto_test_max_per_student_setup_time
             ),
-            "SERVER_TIME_DIFF_TOLERANCE": to_dict(
-                self.server_time_diff_tolerance
-            ),
             "ASSIGNMENT_DEFAULT_GRADING_SCALE": to_dict(
                 self.assignment_default_grading_scale
             ),
@@ -443,9 +528,33 @@ class FrontendSiteSettings:
             "PEER_FEEDBACK_ENABLED": to_dict(self.peer_feedback_enabled),
             "AT_IMAGE_CACHING_ENABLED": to_dict(self.at_image_caching_enabled),
             "STUDENT_PAYMENT_ENABLED": to_dict(self.student_payment_enabled),
+            "EDITOR_ENABLED": to_dict(self.editor_enabled),
+            "SERVER_TIME_CORRECTION_ENABLED": to_dict(
+                self.server_time_correction_enabled
+            ),
+            "METRIC_GATHERING_ENABLED": to_dict(self.metric_gathering_enabled),
             "FEEDBACK_THREADS_INITIALLY_COLLAPSED": to_dict(
                 self.feedback_threads_initially_collapsed
             ),
+            "METRIC_GATHERING_TIME_INTERVAL": to_dict(
+                self.metric_gathering_time_interval
+            ),
+            "METRIC_GATHERING_EVENT_INTERVAL": to_dict(
+                self.metric_gathering_event_interval
+            ),
+            "METRIC_EVENT_BUFFER_SIZE": to_dict(self.metric_event_buffer_size),
+            "METRIC_EVALUATION_TIME_LIMIT": to_dict(
+                self.metric_evaluation_time_limit
+            ),
+            "METRIC_GATHERING_EXPRESSIONS": to_dict(
+                self.metric_gathering_expressions
+            ),
+            "SERVER_TIME_DIFF_TOLERANCE": to_dict(
+                self.server_time_diff_tolerance
+            ),
+            "SERVER_TIME_SYNC_INTERVAL": to_dict(
+                self.server_time_sync_interval
+            ),
         }
         return res
 
@@ -473,7 +582,6 @@ class FrontendSiteSettings:
             max_plagiarism_matches=parsed.MAX_PLAGIARISM_MATCHES,
             auto_test_max_global_setup_time=parsed.AUTO_TEST_MAX_GLOBAL_SETUP_TIME,
             auto_test_max_per_student_setup_time=parsed.AUTO_TEST_MAX_PER_STUDENT_SETUP_TIME,
-            server_time_diff_tolerance=parsed.SERVER_TIME_DIFF_TOLERANCE,
             assignment_default_grading_scale=parsed.ASSIGNMENT_DEFAULT_GRADING_SCALE,
             blackboard_zip_upload_enabled=parsed.BLACKBOARD_ZIP_UPLOAD_ENABLED,
             rubrics_enabled=parsed.RUBRICS_ENABLED,
@@ -490,7 +598,17 @@ class FrontendSiteSettings:
             peer_feedback_enabled=parsed.PEER_FEEDBACK_ENABLED,
             at_image_caching_enabled=parsed.AT_IMAGE_CACHING_ENABLED,
             student_payment_enabled=parsed.STUDENT_PAYMENT_ENABLED,
+            editor_enabled=parsed.EDITOR_ENABLED,
+            server_time_correction_enabled=parsed.SERVER_TIME_CORRECTION_ENABLED,
+            metric_gathering_enabled=parsed.METRIC_GATHERING_ENABLED,
             feedback_threads_initially_collapsed=parsed.FEEDBACK_THREADS_INITIALLY_COLLAPSED,
+            metric_gathering_time_interval=parsed.METRIC_GATHERING_TIME_INTERVAL,
+            metric_gathering_event_interval=parsed.METRIC_GATHERING_EVENT_INTERVAL,
+            metric_event_buffer_size=parsed.METRIC_EVENT_BUFFER_SIZE,
+            metric_evaluation_time_limit=parsed.METRIC_EVALUATION_TIME_LIMIT,
+            metric_gathering_expressions=parsed.METRIC_GATHERING_EXPRESSIONS,
+            server_time_diff_tolerance=parsed.SERVER_TIME_DIFF_TOLERANCE,
+            server_time_sync_interval=parsed.SERVER_TIME_SYNC_INTERVAL,
         )
         res.raw_data = d
         return res
