@@ -27,3 +27,5 @@ class GlobalPermission(str, Enum):
     can_skip_payment = "can_skip_payment"
     can_edit_pricing = "can_edit_pricing"
     can_see_all_transactions = "can_see_all_transactions"
+    can_edit_coupons = "can_edit_coupons"
+    can_see_coupons = "can_see_coupons"
