@@ -2,6 +2,7 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+
 import typing as t
 from dataclasses import dataclass, field
 
@@ -17,6 +18,8 @@ class NonFinalizedLTI1p1Provider(BaseLTI1p1Provider):
 
     #: This is a non finalized provider, so it cannot yet be used for launches.
     finalized: "t.Literal[False]"
+    #: The netloc the LTI provider should be configured on.
+    netloc: "str"
     #: If you have the permission to edit this provider this will be a key with
     #: which you can do that.
     edit_secret: "t.Optional[str]"
@@ -38,6 +41,11 @@ class NonFinalizedLTI1p1Provider(BaseLTI1p1Provider):
                         " used for launches."
                     ),
                 ),
+                rqa.RequiredArgument(
+                    "netloc",
+                    rqa.SimpleValue.str,
+                    doc="The netloc the LTI provider should be configured on.",
+                ),
                 rqa.RequiredArgument(
                     "edit_secret",
                     rqa.Nullable(rqa.SimpleValue.str),
@@ -69,6 +77,7 @@ class NonFinalizedLTI1p1Provider(BaseLTI1p1Provider):
     def to_dict(self) -> t.Dict[str, t.Any]:
         res: t.Dict[str, t.Any] = {
             "finalized": to_dict(self.finalized),
+            "netloc": to_dict(self.netloc),
             "edit_secret": to_dict(self.edit_secret),
             "lms_consumer_key": to_dict(self.lms_consumer_key),
             "lms_consumer_secret": to_dict(self.lms_consumer_secret),
@@ -90,6 +99,7 @@ class NonFinalizedLTI1p1Provider(BaseLTI1p1Provider):
 
         res = cls(
             finalized=parsed.finalized,
+            netloc=parsed.netloc,
             edit_secret=parsed.edit_secret,
             lms_consumer_key=parsed.lms_consumer_key,
             lms_consumer_secret=parsed.lms_consumer_secret,
@@ -103,3 +113,14 @@ class NonFinalizedLTI1p1Provider(BaseLTI1p1Provider):
         )
         res.raw_data = d
         return res
+
+
+import os
+
+if os.getenv("CG_GENERATING_DOCS", "False").lower() in ("", "true"):
+    # fmt: off
+    import datetime
+
+    from .base_lti_provider import BaseLTIProvider
+
+    # fmt: on
