@@ -2,6 +2,7 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+
 import typing as t
 from dataclasses import dataclass, field
 
@@ -17,6 +18,8 @@ class NonFinalizedLTI1p3Provider(BaseLTI1p3Provider):
 
     #: This is a non finalized provider.
     finalized: "t.Literal[False]"
+    #: The domain the launches should be done on.
+    netloc: "str"
     #: The auth login url, if already configured.
     auth_login_url: "t.Optional[str]"
     #: The auth token url, if already configured.
@@ -48,6 +51,11 @@ class NonFinalizedLTI1p3Provider(BaseLTI1p3Provider):
                     rqa.LiteralBoolean(False),
                     doc="This is a non finalized provider.",
                 ),
+                rqa.RequiredArgument(
+                    "netloc",
+                    rqa.SimpleValue.str,
+                    doc="The domain the launches should be done on.",
+                ),
                 rqa.RequiredArgument(
                     "auth_login_url",
                     rqa.Nullable(rqa.SimpleValue.str),
@@ -115,6 +123,7 @@ class NonFinalizedLTI1p3Provider(BaseLTI1p3Provider):
     def to_dict(self) -> t.Dict[str, t.Any]:
         res: t.Dict[str, t.Any] = {
             "finalized": to_dict(self.finalized),
+            "netloc": to_dict(self.netloc),
             "auth_login_url": to_dict(self.auth_login_url),
             "auth_token_url": to_dict(self.auth_token_url),
             "client_id": to_dict(self.client_id),
@@ -144,6 +153,7 @@ class NonFinalizedLTI1p3Provider(BaseLTI1p3Provider):
 
         res = cls(
             finalized=parsed.finalized,
+            netloc=parsed.netloc,
             auth_login_url=parsed.auth_login_url,
             auth_token_url=parsed.auth_token_url,
             client_id=parsed.client_id,
@@ -165,3 +175,18 @@ class NonFinalizedLTI1p3Provider(BaseLTI1p3Provider):
         )
         res.raw_data = d
         return res
+
+
+import os
+
+if os.getenv("CG_GENERATING_DOCS", "False").lower() in ("", "true"):
+    # fmt: off
+    import datetime
+
+    from .base_lti_provider import BaseLTIProvider
+    from .lms_capabilities import LMSCapabilities
+    from .lti1p3_provider_presentation_as_json import (
+        LTI1p3ProviderPresentationAsJSON,
+    )
+
+    # fmt: on
