@@ -62,6 +62,7 @@ from .blackboard_zip_upload_enabled_setting import (
     BlackboardZipUploadEnabledSetting,
 )
 from .course_register_enabled_setting import CourseRegisterEnabledSetting
+from .editor_enabled_setting import EditorEnabledSetting
 from .email_students_enabled_setting import EmailStudentsEnabledSetting
 from .exam_login_max_length_setting import ExamLoginMaxLengthSetting
 from .feedback_threads_initially_collapsed_setting import (
@@ -75,6 +76,9 @@ from .jwt_access_token_expires_setting import JwtAccessTokenExpiresSetting
 from .linters_enabled_setting import LintersEnabledSetting
 from .login_token_before_time_setting import LoginTokenBeforeTimeSetting
 from .lti_enabled_setting import LtiEnabledSetting
+from .max_document_update_size_setting import MaxDocumentUpdateSizeSetting
+from .max_dynamo_file_size_setting import MaxDynamoFileSizeSetting
+from .max_dynamo_submission_size_setting import MaxDynamoSubmissionSizeSetting
 from .max_file_size_setting import MaxFileSizeSetting
 from .max_large_upload_size_setting import MaxLargeUploadSizeSetting
 from .max_lines_setting import MaxLinesSetting
@@ -82,6 +86,21 @@ from .max_mirror_file_age_setting import MaxMirrorFileAgeSetting
 from .max_normal_upload_size_setting import MaxNormalUploadSizeSetting
 from .max_number_of_files_setting import MaxNumberOfFilesSetting
 from .max_plagiarism_matches_setting import MaxPlagiarismMatchesSetting
+from .max_user_setting_amount_setting import MaxUserSettingAmountSetting
+from .metric_evaluation_time_limit_setting import (
+    MetricEvaluationTimeLimitSetting,
+)
+from .metric_event_buffer_size_setting import MetricEventBufferSizeSetting
+from .metric_gathering_enabled_setting import MetricGatheringEnabledSetting
+from .metric_gathering_event_interval_setting import (
+    MetricGatheringEventIntervalSetting,
+)
+from .metric_gathering_expressions_setting import (
+    MetricGatheringExpressionsSetting,
+)
+from .metric_gathering_time_interval_setting import (
+    MetricGatheringTimeIntervalSetting,
+)
 from .min_password_score_setting import MinPasswordScoreSetting
 from .notification_poll_time_setting import NotificationPollTimeSetting
 from .peer_feedback_enabled_setting import PeerFeedbackEnabledSetting
@@ -90,7 +109,12 @@ from .release_message_max_time_setting import ReleaseMessageMaxTimeSetting
 from .render_html_enabled_setting import RenderHtmlEnabledSetting
 from .reset_token_time_setting import ResetTokenTimeSetting
 from .rubrics_enabled_setting import RubricsEnabledSetting
+from .send_registration_email_setting import SendRegistrationEmailSetting
+from .server_time_correction_enabled_setting import (
+    ServerTimeCorrectionEnabledSetting,
+)
 from .server_time_diff_tolerance_setting import ServerTimeDiffToleranceSetting
+from .server_time_sync_interval_setting import ServerTimeSyncIntervalSetting
 from .setting_token_time_setting import SettingTokenTimeSetting
 from .site_email_setting import SiteEmailSetting
 from .student_payment_enabled_setting import StudentPaymentEnabledSetting
@@ -119,7 +143,10 @@ SiteSettingInput = t.Union[
     MaxNumberOfFilesSetting,
     MaxLargeUploadSizeSetting,
     MaxNormalUploadSizeSetting,
+    MaxDynamoSubmissionSizeSetting,
     MaxFileSizeSetting,
+    MaxDynamoFileSizeSetting,
+    MaxDocumentUpdateSizeSetting,
     JwtAccessTokenExpiresSetting,
     MaxLinesSetting,
     NotificationPollTimeSetting,
@@ -128,7 +155,6 @@ SiteSettingInput = t.Union[
     MaxMirrorFileAgeSetting,
     AutoTestMaxGlobalSetupTimeSetting,
     AutoTestMaxPerStudentSetupTimeSetting,
-    ServerTimeDiffToleranceSetting,
     AssignmentDefaultGradingScaleSetting,
     BlackboardZipUploadEnabledSetting,
     RubricsEnabledSetting,
@@ -145,7 +171,19 @@ SiteSettingInput = t.Union[
     PeerFeedbackEnabledSetting,
     AtImageCachingEnabledSetting,
     StudentPaymentEnabledSetting,
+    EditorEnabledSetting,
+    ServerTimeCorrectionEnabledSetting,
+    MetricGatheringEnabledSetting,
     FeedbackThreadsInitiallyCollapsedSetting,
+    MaxUserSettingAmountSetting,
+    SendRegistrationEmailSetting,
+    MetricGatheringTimeIntervalSetting,
+    MetricGatheringEventIntervalSetting,
+    MetricEventBufferSizeSetting,
+    MetricEvaluationTimeLimitSetting,
+    MetricGatheringExpressionsSetting,
+    ServerTimeDiffToleranceSetting,
+    ServerTimeSyncIntervalSetting,
 ]
 SiteSettingInputParser = rqa.Lazy(
     lambda: make_union(
@@ -172,7 +210,10 @@ SiteSettingInputParser = rqa.Lazy(
         ParserFor.make(MaxNumberOfFilesSetting),
         ParserFor.make(MaxLargeUploadSizeSetting),
         ParserFor.make(MaxNormalUploadSizeSetting),
+        ParserFor.make(MaxDynamoSubmissionSizeSetting),
         ParserFor.make(MaxFileSizeSetting),
+        ParserFor.make(MaxDynamoFileSizeSetting),
+        ParserFor.make(MaxDocumentUpdateSizeSetting),
         ParserFor.make(JwtAccessTokenExpiresSetting),
         ParserFor.make(MaxLinesSetting),
         ParserFor.make(NotificationPollTimeSetting),
@@ -181,7 +222,6 @@ SiteSettingInputParser = rqa.Lazy(
         ParserFor.make(MaxMirrorFileAgeSetting),
         ParserFor.make(AutoTestMaxGlobalSetupTimeSetting),
         ParserFor.make(AutoTestMaxPerStudentSetupTimeSetting),
-        ParserFor.make(ServerTimeDiffToleranceSetting),
         ParserFor.make(AssignmentDefaultGradingScaleSetting),
         ParserFor.make(BlackboardZipUploadEnabledSetting),
         ParserFor.make(RubricsEnabledSetting),
@@ -198,6 +238,18 @@ SiteSettingInputParser = rqa.Lazy(
         ParserFor.make(PeerFeedbackEnabledSetting),
         ParserFor.make(AtImageCachingEnabledSetting),
         ParserFor.make(StudentPaymentEnabledSetting),
+        ParserFor.make(EditorEnabledSetting),
+        ParserFor.make(ServerTimeCorrectionEnabledSetting),
+        ParserFor.make(MetricGatheringEnabledSetting),
         ParserFor.make(FeedbackThreadsInitiallyCollapsedSetting),
+        ParserFor.make(MaxUserSettingAmountSetting),
+        ParserFor.make(SendRegistrationEmailSetting),
+        ParserFor.make(MetricGatheringTimeIntervalSetting),
+        ParserFor.make(MetricGatheringEventIntervalSetting),
+        ParserFor.make(MetricEventBufferSizeSetting),
+        ParserFor.make(MetricEvaluationTimeLimitSetting),
+        ParserFor.make(MetricGatheringExpressionsSetting),
+        ParserFor.make(ServerTimeDiffToleranceSetting),
+        ParserFor.make(ServerTimeSyncIntervalSetting),
     ),
 )
