@@ -2,11 +2,16 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import sys
 import typing as t
 
 import cg_request_args as rqa
 from httpx import Response
-from typing_extensions import Protocol
+
+if sys.version_info >= (3, 8):
+    from typing import Protocol
+else:  # pragma: no cover
+    from typing_extensions import Protocol
 
 ModelLikeT = t.TypeVar("ModelLikeT", bound="ModelLike")
 _T = t.TypeVar("_T")
