@@ -22,6 +22,11 @@ from . import parsers
 if t.TYPE_CHECKING:
     from httpx import Response
 
+if sys.version_info >= (3, 8):
+    from typing import Final, Literal, Protocol, TypedDict
+else:  # pragma: no cover
+    from typing_extensions import Final, Literal, Protocol, TypedDict
+
 logger = structlog.get_logger()
 
 T = t.TypeVar("T")
@@ -173,6 +178,14 @@ def log_warnings(response: "Response") -> None:
 
 
 def maybe_input(prompt: str, dflt: str = "") -> cg_maybe.Maybe[str]:
+    """Queries the user for an input.
+
+    :param prompt: The question to ask the user.
+    :param dflt: Default return value.
+
+    :returns: A Just of the user's answer or default, or Nothing in case of
+              error.
+    """
     try:
         res = input(
             "{}{}: ".format(
@@ -189,6 +202,18 @@ def maybe_input(prompt: str, dflt: str = "") -> cg_maybe.Maybe[str]:
 def select_from_list(
     prompt: str, lst: t.Iterable[T], make_label: t.Callable[[T], str]
 ) -> cg_maybe.Maybe[T]:
+    """Queries the user to select one of the values from a list.
+
+    :param prompt: The question to ask the user.
+    :param lst: The list from which to select.
+    :param make_label: A function that generates a label for each value in the
+        list.
+
+    :returns: A Just of the value selected by the user, or Nothing if the
+              selection is invalid
+
+    :rtype: Maybe[T]
+    """
     lst = list(lst)
     max_width = math.ceil(math.log10(len(lst) + 1))
     for idx, item in enumerate(lst):
@@ -208,3 +233,21 @@ def select_from_list(
             return cg_maybe.Just(res)
         except ValueError:
             continue
+
+
+def value_or_exit(
+    maybe_value: cg_maybe.Maybe[T], err_message: str = "Value was undefined"
+) -> T:
+    """Get the value from a Maybe or exit the program with an error message.
+
+    :param maybe_value: The value to extract.
+    :param err_message: THe error message if there is nothing to extract.
+
+    :returns: The contained value.
+    """
+
+    def _make_exception() -> Exception:
+        print(err_message)
+        return sys.exit(1)
+
+    return maybe_value.try_extract(_make_exception)
